@@ -57,7 +57,7 @@ std::string getString(unsigned val)
   return res;
 }
 
-bool readBitmap(Stream &stream, MWAWEmbeddedObject &object, MWAWColor *avgColor)
+bool readBitmap(Stream &stream, int version, MWAWEmbeddedObject &object, MWAWColor *avgColor)
 {
   object=MWAWEmbeddedObject();
   auto input=stream.input();
@@ -151,7 +151,8 @@ bool readBitmap(Stream &stream, MWAWEmbeddedObject &object, MWAWColor *avgColor)
 
   pos=input->tell();
   int const width=type==0 ? (dimension[0]+7)/8 : dimension[0];
-  long dataLength=((type==3||type==4) ? numPlanes : 1)*(20+width*dimension[1]);
+  int const planeHeaderLength=(version<9 ? 20 : 40);
+  long dataLength=((type==3||type==4) ? numPlanes : 1)*(planeHeaderLength+width*dimension[1]);
   if (width<=0 || dimension[1]<=0 || pos+dataLength<pos || !input->checkPosition(pos+dataLength)) {
     MWAW_DEBUG_MSG(("Canvas5Structure::readBitmap: can not find the bitmap data\n"));
     f << "###";
@@ -203,11 +204,11 @@ bool readBitmap(Stream &stream, MWAWEmbeddedObject &object, MWAWColor *avgColor)
     pos=input->tell();
     f.str("");
     f << "Bitmap-P" << plane << ":";
-    for (int i=0; i<6; ++i) {
-      val=int(input->readLong(2));
-      int const expected[]= {0,2,0,8,0,1};
+    for (int i=0; i<3; ++i) {
+      val=int(input->readLong(4));
+      int const expected[]= {2 /* or 3*/,8,1};
       if (val==expected[i]) continue;
-      if (i==3)
+      if (i==1)
         f << "num[bytes]=" << val << ",";
       else
         f << "g" << i << "=" << val << ",";
@@ -216,6 +217,7 @@ bool readBitmap(Stream &stream, MWAWEmbeddedObject &object, MWAWColor *avgColor)
     dim1=MWAWVec2i(dim[1], dim[0]);
     if (dimension!=dim1)
       f << "dim2=" << dim1 << ",";
+    input->seek(pos+planeHeaderLength, librevenge::RVNG_SEEK_SET);
     ascFile.addPos(pos);
     ascFile.addNote(f.str().c_str());
 
@@ -281,9 +283,9 @@ bool readBitmap(Stream &stream, MWAWEmbeddedObject &object, MWAWColor *avgColor)
   return ok && !object.m_dataList.empty();
 }
 
-bool readBitmapDAD58Bim(Stream &stream, MWAWEmbeddedObject &object)
+bool readBitmapDAD58Bim(Stream &stream, int version, MWAWEmbeddedObject &object)
 {
-  if (!readBitmap(stream, object))
+  if (!readBitmap(stream, version, object))
     return false;
 
   auto input=stream.input();
@@ -508,6 +510,104 @@ bool readBitmapDAD58Bim(Stream &stream, MWAWEmbeddedObject &object)
   }
 
   input->seek(endBimBlock, librevenge::RVNG_SEEK_SET);
+
+  if (version<9)
+    return true;
+
+  if (input->isEnd()) // bitmap in cvi file ends here
+    return true;
+  // last block: unknown
+  pos=input->tell();
+  len=input->readLong(4);
+  f.str("");
+  f << "Bitmap[unknown]:";
+  long endUnknownBlock=pos+4+len;
+  if (len<0 || endUnknownBlock<pos+4 || !input->checkPosition(endUnknownBlock)) {
+    MWAW_DEBUG_MSG(("Canvas5Structure::readBitmapDAD58Bim: can not read unknown block\n"));
+    f << "###";
+    ascFile.addPos(pos);
+    ascFile.addNote(f.str().c_str());
+    return false;
+  }
+  if (len) {
+    MWAW_DEBUG_MSG(("Canvas5Structure::readBitmapDAD58Bim: find an unknown block\n"));
+    f << "###";
+    ascFile.addPos(pos);
+    ascFile.addNote(f.str().c_str());
+    input->seek(endUnknownBlock, librevenge::RVNG_SEEK_SET);
+  }
+  else {
+    ascFile.addPos(pos);
+    ascFile.addNote("_");
+  }
+  return true;
+}
+
+bool readPreview(Stream &stream, bool hasPreviewBitmap)
+{
+  auto input=stream.input();
+  if (!input) return false;
+  long pos=input->tell();
+  if (!input->checkPosition(pos+12+(hasPreviewBitmap ? 12 : 0))) {
+    MWAW_DEBUG_MSG(("Canvas5Structure::readPreview: the zone is too short\n"));
+    return false;
+  }
+  libmwaw::DebugStream f;
+  auto &ascFile=stream.ascii();
+  f << "Entries(Preview):";
+  int dims[3];
+  for (auto &d : dims) d=int(input->readLong(4));
+  f << "dim=" << MWAWVec2i(dims[1], dims[0]) << "[" << dims[2] << "],";
+  int width=hasPreviewBitmap ? int(input->readLong(4)) : 0;
+  if (width) f << "w=" << width << ",";
+  long endPos=pos+(hasPreviewBitmap ? 24 : 12)+long(width*dims[0]);
+  if (!hasPreviewBitmap || dims[0]<=0 || dims[1]<=0 || dims[2]!=3 || width<dims[1]*dims[2] ||
+      endPos<=pos+24 || !input->checkPosition(endPos)) {
+    if (dims[0]==0 && dims[1]==0 && input->checkPosition(endPos)) {
+      ascFile.addPos(pos);
+      ascFile.addNote(f.str().c_str());
+      input->seek(endPos, librevenge::RVNG_SEEK_SET);
+      ascFile.skipZone(input->tell(), endPos-1);
+      return true;
+    }
+    f << "###";
+    MWAW_DEBUG_MSG(("Canvas5Structure::readPreview: the dimensions seems bad\n"));
+    ascFile.addPos(pos);
+    ascFile.addNote(f.str().c_str());
+    return false;
+  }
+  for (int i=0; i<2; ++i) {
+    int val=int(input->readLong(4));
+    int const expected[]= {3,1};
+    if (val!=expected[i])
+      f << "f" << i << "=" << val << ",";
+  }
+  ascFile.addPos(pos);
+  ascFile.addNote(f.str().c_str());
+
+  pos=input->tell();
+  MWAWPictBitmapColor pict(MWAWVec2i(dims[1], dims[0]), dims[2]==4);
+  for (int y=0; y<dims[0]; ++y) {
+    long actPos=input->tell();
+    unsigned char cols[4]= {0,0,0,0};
+    for (int w=0; w<dims[1]; ++w) {
+      for (int c=0; c<dims[2]; ++c) cols[c]=(unsigned char)(input->readULong(1));
+      if (dims[2]==4)
+        pict.set(w, y, MWAWColor(cols[1], cols[2], cols[3], (unsigned char)(255-cols[0])));
+      else
+        pict.set(w, y, MWAWColor(cols[0], cols[1], cols[2]));
+    }
+    input->seek(actPos+width, librevenge::RVNG_SEEK_SET);
+  }
+
+  input->seek(endPos, librevenge::RVNG_SEEK_SET);
+  ascFile.skipZone(pos, endPos-1);
+#ifdef DEBUG_WITH_FILES
+  MWAWEmbeddedObject obj;
+  if (pict.getBinary(obj) && !obj.m_dataList.empty())
+    libmwaw::Debug::dumpFile(obj.m_dataList[0], "file.png");
+#endif
+
   return true;
 }
 
