@@ -121,6 +121,8 @@ struct Paragraph final : public MWAWParagraph {
     , m_labelType(0)
   {
   }
+  Paragraph(Paragraph const &)=default;
+  Paragraph &operator=(Paragraph const &)=default;
   //! destructor
   ~Paragraph() final;
   //! operator<<
@@ -1322,7 +1324,7 @@ bool ClarisWksText::readTextSection(ClarisWksTextInternal::Zone &zone)
 
   ClarisWksTextInternal::PLC plc;
   plc.m_type = ClarisWksTextInternal::P_Section;
-  for (int i= 0; i < header.m_numData; i++) {
+  for (long i= 0; i < header.m_numData; i++) {
     ClarisWksTextInternal::Section sec;
 
     pos = input->tell();
@@ -1389,7 +1391,7 @@ bool ClarisWksText::readTextSection(ClarisWksTextInternal::Zone &zone)
     }
     sec.m_extra = f.str();
     zone.m_sectionList.push_back(sec);
-    plc.m_id = i;
+    plc.m_id = int(i);
     zone.m_plcMap.insert(std::map<long, ClarisWksTextInternal::PLC>::value_type(sec.m_pos, plc));
     f.str("");
     f << "TextSection-S" << i << ":" << sec;
@@ -1875,9 +1877,9 @@ bool ClarisWksText::readParagraphs()
   ascFile.addPos(pos);
   ascFile.addNote(f.str().c_str());
 
-  for (int i = 0; i < header.m_numData; i++) {
+  for (long i = 0; i < header.m_numData; i++) {
     pos = input->tell();
-    if (!readParagraph(i)) {
+    if (!readParagraph(int(i))) {
       input->seek(pos, librevenge::RVNG_SEEK_SET);
       return false;
     }
@@ -1915,6 +1917,10 @@ bool ClarisWksText::readParagraph(int id)
   MWAWInputStreamPtr &input= m_parserState->m_input;
   long pos = input->tell();
   long endPos = pos+dataSize;
+  if (!input->checkPosition(endPos)) {
+    MWAW_DEBUG_MSG(("ClarisWksText::readParagraph: the zone seems too short\n"));
+    return false;
+  }
   libmwaw::DebugFile &ascFile = m_parserState->m_asciiFile;
   libmwaw::DebugStream f;
 
