@@ -62,7 +62,11 @@ namespace EDocParserInternal
 //! Internal: an index of a EDocParser
 struct Index {
   //! constructor
-  Index() : m_levelId(0), m_text(""), m_page(-1), m_extra("")
+  Index()
+    : m_levelId(0)
+    , m_text("")
+    , m_page(-1)
+    , m_extra("")
   {
   }
   //! operator<<
@@ -88,8 +92,16 @@ struct Index {
 //! Internal: the state of a EDocParser
 struct State {
   //! constructor
-  State() : m_compressed(false), m_maxPictId(0), m_idCPICMap(), m_idPICTMap(),
-    m_indexList(), m_actPage(0), m_numPages(0), m_headerHeight(0), m_footerHeight(0)
+  State()
+    : m_compressed(false)
+    , m_maxPictId(0)
+    , m_idCPICMap()
+    , m_idPICTMap()
+    , m_indexList()
+    , m_actPage(0)
+    , m_numPages(0)
+    , m_headerHeight(0)
+    , m_footerHeight(0)
   {
   }
   //! a flag to know if the data are compressed or not
@@ -113,8 +125,9 @@ struct State {
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-EDocParser::EDocParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWTextParser(input, rsrcParser, header), m_state()
+EDocParser::EDocParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWTextParser(input, rsrcParser, header)
+  , m_state()
 {
   init();
 }
@@ -164,10 +177,10 @@ void EDocParser::newPage(int number)
 ////////////////////////////////////////////////////////////
 void EDocParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  if (!getInput().get() || !getRSRCParser() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !getRSRCParser() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
@@ -203,7 +216,7 @@ void EDocParser::createDocument(librevenge::RVNGTextInterface *documentInterface
 
   // create the page list
   int numPages = m_state->m_maxPictId;
-  if (m_state->m_indexList.size())
+  if (!m_state->m_indexList.empty())
     numPages++;
   if (numPages <= 0) numPages=1;
   m_state->m_numPages=numPages;
@@ -226,11 +239,10 @@ void EDocParser::createDocument(librevenge::RVNGTextInterface *documentInterface
 bool EDocParser::createZones()
 {
   MWAWRSRCParserPtr rsrcParser = getRSRCParser();
-  std::multimap<std::string, MWAWEntry> &entryMap = rsrcParser->getEntriesMap();
-  std::multimap<std::string, MWAWEntry>::iterator it;
+  auto &entryMap = rsrcParser->getEntriesMap();
 
   // the 128 zone
-  it = entryMap.lower_bound("eDcF");
+  auto it = entryMap.lower_bound("eDcF");
   while (it != entryMap.end()) {
     if (it->first != "eDcF")
       break;
@@ -255,7 +267,7 @@ bool EDocParser::createZones()
 #ifdef DEBUG_WITH_FILES
   // get rid of the default application resource
   libmwaw::DebugFile &ascFile = rsrcAscii();
-  static char const *(appliRsrc[])= {
+  static char const *appliRsrc[]= {
     // default, Dialog (3000: DLOG,DITL,DLGX,dctb","ictb","STR ")
     "ALRT","BNDL","CNTL","CURS","CDEF", "DLOG","DLGX","DITL","FREF","ICON",
     "ICN#","MENU","SIZE","WIND",
@@ -281,18 +293,17 @@ bool EDocParser::createZones()
 bool EDocParser::findContents()
 {
   MWAWRSRCParserPtr rsrcParser = getRSRCParser();
-  std::multimap<std::string, MWAWEntry> &entryMap = rsrcParser->getEntriesMap();
-  std::multimap<std::string, MWAWEntry>::iterator it;
+  auto &entryMap = rsrcParser->getEntriesMap();
 
   /* if the data is compress, we must look for cPIC zone ; if not,
      we look for the first PICT zone.
      Note: maybe we can also find text in TEXT zone, but I never see that
    */
-  char const *(wh[2])= {"cPIC", "PICT"};
+  char const *wh[2]= {"cPIC", "PICT"};
   for (int st = 0; st < 2; st++) {
     std::map<int, MWAWEntry> &map=st==0 ? m_state->m_idCPICMap : m_state->m_idPICTMap;
     std::set<int> seens;
-    it = entryMap.lower_bound(wh[st]);
+    auto it = entryMap.lower_bound(wh[st]);
     while (it != entryMap.end()) {
       if (it->first != wh[st])
         break;
@@ -302,7 +313,7 @@ bool EDocParser::findContents()
     }
     if (seens.empty() || m_state->m_maxPictId)
       continue;
-    std::set<int>::iterator sIt=seens.lower_bound(1);
+    auto sIt=seens.lower_bound(1);
     if (sIt==seens.end()|| *sIt>10)
       continue;
     int maxId=*sIt;
@@ -323,7 +334,7 @@ bool EDocParser::sendContents()
     newPage(++actPage);
     sendPicture(i, compressed);
   }
-  if (m_state->m_indexList.size()) {
+  if (!m_state->m_indexList.empty()) {
     newPage(++actPage);
     sendIndex();
   }
@@ -350,7 +361,7 @@ bool EDocParser::sendPicture(int pictId, bool compressed)
       return false;
   }
 
-  int dataSz=int(data.size());
+  auto dataSz=int(data.size());
   if (!dataSz)
     return false;
   MWAWInputStreamPtr pictInput=MWAWInputStream::get(data, false);
@@ -359,13 +370,13 @@ bool EDocParser::sendPicture(int pictId, bool compressed)
     return false;
   }
   MWAWBox2f box;
-  MWAWPict::ReadResult res = MWAWPictData::check(pictInput, dataSz,box);
+  auto res = MWAWPictData::check(pictInput, dataSz,box);
   if (res == MWAWPict::MWAW_R_BAD) {
     MWAW_DEBUG_MSG(("EDocParser::sendPicture: can not find the picture\n"));
     return false;
   }
   pictInput->seek(0,librevenge::RVNG_SEEK_SET);
-  shared_ptr<MWAWPict> thePict(MWAWPictData::get(pictInput, dataSz));
+  std::shared_ptr<MWAWPict> thePict(MWAWPictData::get(pictInput, dataSz));
   MWAWPosition pictPos=MWAWPosition(MWAWVec2f(0,0),box.size(), librevenge::RVNG_POINT);
   pictPos.setRelativePosition(MWAWPosition::Char);
   if (thePict) {
@@ -379,15 +390,13 @@ bool EDocParser::sendPicture(int pictId, bool compressed)
 void EDocParser::flushExtra()
 {
 #ifdef DEBUG
-  std::map<int, MWAWEntry>::const_iterator rIt = m_state->m_idCPICMap.begin();
-  for (; rIt != m_state->m_idCPICMap.end(); ++rIt) {
-    MWAWEntry const &entry = rIt->second;
+  for (auto rIt : m_state->m_idCPICMap) {
+    MWAWEntry const &entry = rIt.second;
     if (entry.isParsed()) continue;
     sendPicture(entry.id(), true);
   }
-  rIt = m_state->m_idPICTMap.begin();
-  for (; rIt != m_state->m_idPICTMap.end(); ++rIt) {
-    MWAWEntry const &entry = rIt->second;
+  for (auto rIt : m_state->m_idPICTMap) {
+    MWAWEntry const &entry = rIt.second;
     if (entry.isParsed()) continue;
     sendPicture(entry.id(), false);
   }
@@ -419,7 +428,7 @@ bool EDocParser::readFontsName(MWAWEntry const &entry)
   f << "Entries(FontsName):";
   if (entry.id()!=128)
     f << "#id=" << entry.id() << ",";
-  int N=static_cast<int>(input->readULong(2));
+  auto N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   ascFile.addPos(pos-4);
   ascFile.addNote(f.str().c_str());
@@ -432,7 +441,7 @@ bool EDocParser::readFontsName(MWAWEntry const &entry)
 
     f.str("");
     f << "FontsName-" << i << ":";
-    int fSz=static_cast<int>(input->readULong(1));
+    auto fSz=static_cast<int>(input->readULong(1));
     if (!fSz || fSz >= 255) {
       f << "##" << fSz << ",";
       MWAW_DEBUG_MSG(("EDocParser::readFontsName: the font name %d seems bad\n", i));
@@ -445,7 +454,7 @@ bool EDocParser::readFontsName(MWAWEntry const &entry)
     }
     input->seek(pos+32, librevenge::RVNG_SEEK_SET);
     for (int j = 0; j < 112; j++) { // always 0 .
-      int val = static_cast<int>(input->readLong(2));
+      auto val = static_cast<int>(input->readLong(2));
       if (val) f << "f" << j << "=" << val << ",";
     }
     ascFile.addPos(pos);
@@ -481,13 +490,12 @@ bool EDocParser::sendIndex()
 
   getTextListener()->insertEOL();
   std::stringstream ss;
-  for (size_t i=0; i <  m_state->m_indexList.size(); i++) {
-    EDocParserInternal::Index const &index = m_state->m_indexList[i];
+  for (auto const &index : m_state->m_indexList) {
     para.m_margins[0] = 0.3*double(index.m_levelId+1);
     getTextListener()->setParagraph(para);
     getTextListener()->setFont(actFont);
-    for (size_t c=0; c < index.m_text.length(); c++)
-      getTextListener()->insertCharacter(static_cast<unsigned char>(index.m_text[c]));
+    for (char c : index.m_text)
+      getTextListener()->insertCharacter(static_cast<unsigned char>(c));
 
     if (index.m_page >= 0) {
       getTextListener()->setFont(cFont);
@@ -519,10 +527,10 @@ bool EDocParser::readIndex(MWAWEntry const &entry)
   f << "Entries(Index):";
   if (entry.id()!=128)
     f << "#id=" << entry.id() << ",";
-  int val=static_cast<int>(input->readULong(2));
+  auto val=static_cast<int>(input->readULong(2));
   if (val) // 100 ?
     f << "f0=" << std::hex << val << std::dec << ",";
-  int N=static_cast<int>(input->readULong(2));
+  auto N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   for (int i = 0; i < 8; i++) { // always 0
     val=static_cast<int>(input->readLong(2));
@@ -558,7 +566,7 @@ bool EDocParser::readIndex(MWAWEntry const &entry)
       if (val)
         f << "f" << j << "=" << val << ",";
     }
-    int fSz = static_cast<int>(input->readULong(1));
+    auto fSz = static_cast<int>(input->readULong(1));
     if (pos+13+fSz > endPos) {
       index.m_extra=f.str();
       f.str("");
@@ -612,7 +620,7 @@ bool EDocParser::readInfo(MWAWEntry const &entry)
   }
   // creator, file name
   for (int i = 0; i < 2; i++) {
-    int sz=static_cast<int>(input->readULong(1));
+    auto sz=static_cast<int>(input->readULong(1));
     if (sz > 31) {
       MWAW_DEBUG_MSG(("EDocParser::readInfo: can not read string %d\n", i));
       f << "###,";
@@ -631,7 +639,7 @@ bool EDocParser::readInfo(MWAWEntry const &entry)
       f << "g" << i << "=" << val << ",";
   }
   int dim[2];
-  for (int i = 0; i < 2; i++) dim[i] = static_cast<int>(input->readLong(2));
+  for (auto &d : dim) d = static_cast<int>(input->readLong(2));
   f << "dim?=" << dim[1] << "x" << dim[0] << ",";
   if (dim[1]>100 && dim[1]<2000 && dim[0]>100 && dim[0]< 2000) {
     getPageSpan().setFormLength(double(dim[0])/72.);
@@ -641,7 +649,7 @@ bool EDocParser::readInfo(MWAWEntry const &entry)
     MWAW_DEBUG_MSG(("EDocParser::readInfo: the page dimension seems bad\n"));
     f << "###,";
   }
-  int N=static_cast<int>(input->readLong(2));
+  auto N=static_cast<int>(input->readLong(2));
   f << "numPict?=" << N << ","; // seems ok in eDcR, but no in eSRD
   for (int i = 0; i < 2; i++) { // fl0=hasIndex ?, fl1=0
     val = static_cast<int>(input->readLong(1));
@@ -672,8 +680,13 @@ namespace EDocParserInternal
 //! very low structure to help uncompress data
 struct DeflateStruct {
   //! constructor
-  DeflateStruct(long size, long initSize) : m_toWrite(size), m_data(),
-    m_circQueue(0x2000,0), m_circQueuePos(0), m_numDelayed(0), m_delayedChar('\0')
+  DeflateStruct(long size, long initSize)
+    : m_toWrite(size)
+    , m_data()
+    , m_circQueue(0x2000,0)
+    , m_circQueuePos(0)
+    , m_numDelayed(0)
+    , m_delayedChar('\0')
   {
     m_data.reserve(size_t(initSize));
   }
@@ -728,8 +741,8 @@ protected:
   //! the delayed character
   unsigned char m_delayedChar;
 private:
-  DeflateStruct(DeflateStruct const &orig);
-  DeflateStruct &operator=(DeflateStruct const &orig);
+  DeflateStruct(DeflateStruct const &orig) = delete;
+  DeflateStruct &operator=(DeflateStruct const &orig) = delete;
 };
 
 bool DeflateStruct::sendDuplicated(int num, int depl)
@@ -804,7 +817,7 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
     MWAW_DEBUG_MSG(("EDocParser::decodeZone: unexpected zone size\n"));
     return false;
   }
-  long zoneSize=long(input->readULong(4));
+  auto zoneSize=long(input->readULong(4));
   f << "sz[final]=" << std::hex << zoneSize << std::dec << ",";
 
   if (!zoneSize) {
@@ -831,7 +844,7 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
       pos=input->tell();
       f.str("");
       f << "CompressZone[data" << st << "]:";
-      int num=static_cast<int>(input->readULong(1));
+      auto num=static_cast<int>(input->readULong(1));
       f << "num=" << num << ",";
       if (num > maxData[st] || pos+1+num > endPos) {
         MWAW_DEBUG_MSG(("EDocParser::decodeZone: find unexpected num of data : %d for zone %d\n", num, st));
@@ -855,9 +868,8 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
       }
       vectors32K[st].resize(0x8000,0);
       int writePos=0;
-      std::multimap<int,int>::const_iterator it;
-      for (it=mapData.begin(); it != mapData.end(); ++it) {
-        int n=0x8000>>(it->first);
+      for (auto it : mapData) {
+        int n=0x8000>>(it.first);
         if (writePos+n>0x8000) {
           MWAW_DEBUG_MSG(("EDocParser::decodeZone: find unexpected value writePos=%x for zone %d\n",static_cast<unsigned int>(writePos+n), st));
 
@@ -868,7 +880,7 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
           return false;
         }
         for (int j = 0; j < n; j++)
-          vectors32K[st][size_t(writePos++)]=static_cast<unsigned char>(it->second);
+          vectors32K[st][size_t(writePos++)]=static_cast<unsigned char>(it.second);
       }
 
       ascFile.addPos(pos);
@@ -882,7 +894,7 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
       if (deflate.isEnd() || input->tell()>endPos) break;
       int ind0=(value>>16);
       if (ind0 & 0x8000) {
-        int ind1 = static_cast<int>(vectors32K[0][size_t(ind0&0x7FFF)]);
+        auto ind1 = static_cast<int>(vectors32K[0][size_t(ind0&0x7FFF)]);
         int byt1=originalValues[0][size_t(ind1)]+1;
         if (byte<byt1) {
           value = (value<<byte);
@@ -898,7 +910,7 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
         continue;
       }
 
-      int ind1 = static_cast<int>(vectors32K[1][size_t(ind0)]);
+      auto ind1 = static_cast<int>(vectors32K[1][size_t(ind0)]);
       int byt1 = originalValues[1][size_t(ind1)]+1;
       if (byte<byt1) {
         value = (value<<byte);
@@ -908,7 +920,7 @@ bool EDocParser::decodeZone(MWAWEntry const &entry, librevenge::RVNGBinaryData &
       }
       value=(value<<byt1);
       byte-=byt1;
-      int ind2 = static_cast<int>(vectors32K[2][size_t(value>>17)]);
+      auto ind2 = static_cast<int>(vectors32K[2][size_t(value>>17)]);
       int byt2=originalValues[2][size_t(ind2)];
       if (byte<byt2) {
         value = (value<<byte);
@@ -968,7 +980,7 @@ bool EDocParser::checkHeader(MWAWHeader *header, bool strict)
   }
   if (strict) {
     // check that the fontname zone exists
-    std::multimap<std::string, MWAWEntry> &entryMap = getRSRCParser()->getEntriesMap();
+    auto &entryMap = getRSRCParser()->getEntriesMap();
     if (entryMap.find("eDcF") == entryMap.end())
       return false;
   }
