@@ -437,13 +437,14 @@ bool HanMacWrdJParser::checkEntry(MWAWEntry &entry)
   entry.setId(type);
   entry.setLength(length);
 
-  static char const *(what[]) = {
-    "FontDef", "Ruler", "Style", "FrameDef", "TZoneList",
-    "TextZone", "Picture", "Table", "GraphData", "GroupData",
-    "ZoneA", "ZoneB", "Section", "FtnDef", "ZoneE", "FontsName"
-  };
-  if (type>=0 && type <= 15)
+  if (type>=0 && type <= 15) {
+    static char const *what[] = {
+      "FontDef", "Ruler", "Style", "FrameDef", "TZoneList",
+      "TextZone", "Picture", "Table", "GraphData", "GroupData",
+      "ZoneA", "ZoneB", "Section", "FtnDef", "ZoneE", "FontsName"
+    };
     entry.setName(what[type]);
+  }
   else {
     std::stringstream s;
     s << "Zone" << std::hex << type << std::dec;
