@@ -66,6 +66,7 @@ struct Paragraph final : public MWAWParagraph {
   {
   }
   Paragraph &operator=(Paragraph const &)=default;
+  Paragraph &operator=(Paragraph &&)=default;
   //! destructor
   ~Paragraph() final;
   //! operator<<
@@ -180,6 +181,7 @@ struct Token {
   {
   }
   Token &operator=(Token const &)=default;
+  Token &operator=(Token &&)=default;
   //! destructor
   ~Token()
   {
