@@ -74,9 +74,17 @@ enum { PageBreakBit=0x1, ColumnBreakBit=0x2 };
 //! a class to store the document state of a MWAWTextListener
 struct DocumentState {
   //! constructor
-  explicit DocumentState(std::vector<MWAWPageSpan> const &pageList) :
-    m_pageList(pageList), m_pageSpan(), m_metaData(), m_footNoteNumber(0), m_endNoteNumber(0), m_smallPictureNumber(0),
-    m_isDocumentStarted(false), m_isHeaderFooterStarted(false), m_sentListMarkers(), m_subDocuments()
+  explicit DocumentState(std::vector<MWAWPageSpan> const &pageList)
+    : m_pageList(pageList)
+    , m_pageSpan()
+    , m_metaData()
+    , m_footNoteNumber(0)
+    , m_endNoteNumber(0)
+    , m_smallPictureNumber(0)
+    , m_isDocumentStarted(false)
+    , m_isHeaderFooterStarted(false)
+    , m_sentListMarkers()
+    , m_subDocuments()
   {
   }
   //! destructor
@@ -100,8 +108,8 @@ struct DocumentState {
   std::vector<MWAWSubDocumentPtr> m_subDocuments; /** list of document actually open */
 
 private:
-  DocumentState(const DocumentState &);
-  DocumentState &operator=(const DocumentState &);
+  DocumentState(const DocumentState &) = delete;
+  DocumentState &operator=(const DocumentState &) = delete;
 };
 
 /** the state of a MWAWTextListener */
@@ -123,7 +131,7 @@ struct State {
   //! a sequence of bit used to know if we need page/column break
   int m_paragraphNeedBreak;
 
-  shared_ptr<MWAWList> m_list;
+  std::shared_ptr<MWAWList> m_list;
 
   bool m_isPageSpanOpened;
   bool m_isSectionOpened;
@@ -161,48 +169,62 @@ struct State {
   libmwaw::SubDocumentType m_subDocumentType;
 
 private:
-  State(const State &);
-  State &operator=(const State &);
+  State(const State &) = delete;
+  State &operator=(const State &) = delete;
 };
 
-State::State() :
-  m_textBuffer(""), m_numDeferredTabs(0),
+State::State()
+  : m_textBuffer("")
+  , m_numDeferredTabs(0)
 
-  m_font(20,12), // default time 12
+  , m_font(20,12) // default time 12
 
-  m_paragraph(), m_paragraphNeedBreak(0),
+  , m_paragraph()
+  , m_paragraphNeedBreak(0)
 
-  m_list(),
+  , m_list()
 
-  m_isPageSpanOpened(false), m_isSectionOpened(false), m_isFrameOpened(false),
-  m_isPageSpanBreakDeferred(false),
-  m_isHeaderFooterWithoutParagraph(false),
-  m_isGroupOpened(false),
+  , m_isPageSpanOpened(false)
+  , m_isSectionOpened(false)
+  , m_isFrameOpened(false)
+  , m_isPageSpanBreakDeferred(false)
+  , m_isHeaderFooterWithoutParagraph(false)
+  , m_isGroupOpened(false)
 
-  m_isSpanOpened(false), m_isParagraphOpened(false), m_isListElementOpened(false),
+  , m_isSpanOpened(false)
+  , m_isParagraphOpened(false)
+  , m_isListElementOpened(false)
 
-  m_firstParagraphInPageSpan(true),
+  , m_firstParagraphInPageSpan(true)
 
-  m_isTableOpened(false), m_isTableRowOpened(false), m_isTableColumnOpened(false),
-  m_isTableCellOpened(false),
+  , m_isTableOpened(false)
+  , m_isTableRowOpened(false)
+  , m_isTableColumnOpened(false)
+  , m_isTableCellOpened(false)
 
-  m_currentPage(0), m_numPagesRemainingInSpan(0), m_currentPageNumber(1),
+  , m_currentPage(0)
+  , m_numPagesRemainingInSpan(0)
+  , m_currentPageNumber(1)
 
-  m_sectionAttributesChanged(false),
-  m_section(),
+  , m_sectionAttributesChanged(false)
+  , m_section()
 
-  m_listOrderedLevels(),
+  , m_listOrderedLevels()
 
-  m_inSubDocument(false),
-  m_isNote(false), m_inLink(false),
-  m_subDocumentType(libmwaw::DOC_NONE)
+  , m_inSubDocument(false)
+  , m_isNote(false)
+  , m_inLink(false)
+  , m_subDocumentType(libmwaw::DOC_NONE)
 {
 }
 }
 
-MWAWTextListener::MWAWTextListener(MWAWParserState &parserState, std::vector<MWAWPageSpan> const &pageList, librevenge::RVNGTextInterface *documentInterface) : MWAWListener(),
-  m_ds(new MWAWTextListenerInternal::DocumentState(pageList)), m_ps(new MWAWTextListenerInternal::State), m_psStack(),
-  m_parserState(parserState), m_documentInterface(documentInterface)
+MWAWTextListener::MWAWTextListener(MWAWParserState &parserState, std::vector<MWAWPageSpan> const &pageList, librevenge::RVNGTextInterface *documentInterface)
+  : MWAWListener()
+  , m_ds(new MWAWTextListenerInternal::DocumentState(pageList))
+  , m_ps(new MWAWTextListenerInternal::State), m_psStack()
+  , m_parserState(parserState)
+  , m_documentInterface(documentInterface)
 {
 }
 
@@ -562,7 +584,7 @@ void MWAWTextListener::_openPageSpan(bool sendHeaderFooters)
     throw libmwaw::ParseException();
   }
   unsigned actPage = 0;
-  std::vector<MWAWPageSpan>::iterator it = m_ds->m_pageList.begin();
+  auto it = m_ds->m_pageList.begin();
   ++m_ps->m_currentPage;
   while (true) {
     actPage+=static_cast<unsigned>(it->getPageSpan());
@@ -614,7 +636,7 @@ bool MWAWTextListener::isHeaderFooterOpened() const
   return m_ds->m_isHeaderFooterStarted;
 }
 
-bool MWAWTextListener::insertHeader(MWAWSubDocumentPtr subDocument, librevenge::RVNGPropertyList const &extras)
+bool MWAWTextListener::insertHeader(MWAWSubDocumentPtr const &subDocument, librevenge::RVNGPropertyList const &extras)
 {
   if (m_ds->m_isHeaderFooterStarted) {
     MWAW_DEBUG_MSG(("MWAWTextListener::insertHeader: Oops a header/footer is already opened\n"));
@@ -627,7 +649,7 @@ bool MWAWTextListener::insertHeader(MWAWSubDocumentPtr subDocument, librevenge::
   return true;
 }
 
-bool MWAWTextListener::insertFooter(MWAWSubDocumentPtr subDocument, librevenge::RVNGPropertyList const &extras)
+bool MWAWTextListener::insertFooter(MWAWSubDocumentPtr const &subDocument, librevenge::RVNGPropertyList const &extras)
 {
   if (m_ds->m_isHeaderFooterStarted) {
     MWAW_DEBUG_MSG(("MWAWTextListener::insertFooter: Oops a header/footer is already opened\n"));
@@ -852,7 +874,7 @@ void MWAWTextListener::_closeListElement()
 
 int MWAWTextListener::_getListId() const
 {
-  size_t newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get());
+  auto newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get());
   if (newLevel == 0) return -1;
   int newListId = m_ps->m_paragraph.m_listId.get();
   if (newListId > 0) return newListId;
@@ -861,8 +883,7 @@ int MWAWTextListener::_getListId() const
     MWAW_DEBUG_MSG(("MWAWTextListener::_getListId: the list id is not set, try to find a new one\n"));
     first = false;
   }
-  shared_ptr<MWAWList> list=m_parserState.m_listManager->getNewList
-                            (m_ps->m_list, int(newLevel), *m_ps->m_paragraph.m_listLevel);
+  auto list=m_parserState.m_listManager->getNewList(m_ps->m_list, int(newLevel), *m_ps->m_paragraph.m_listLevel);
   if (!list) return -1;
   return list->getId();
 }
@@ -873,7 +894,7 @@ void MWAWTextListener::_changeList()
     _closeParagraph();
 
   size_t actualLevel = m_ps->m_listOrderedLevels.size();
-  size_t newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get() > 0 ? m_ps->m_paragraph.m_listLevelIndex.get() : 0);
+  auto newLevel= size_t(m_ps->m_paragraph.m_listLevelIndex.get() > 0 ? m_ps->m_paragraph.m_listLevelIndex.get() : 0);
   if (newLevel>100) {
     MWAW_DEBUG_MSG(("MWAWTextListener::_changeList: find level=%d, set it to 100\n", static_cast<int>(newLevel)));
     newLevel=100;
@@ -894,7 +915,7 @@ void MWAWTextListener::_changeList()
   }
 
   if (newLevel) {
-    shared_ptr<MWAWList> theList;
+    std::shared_ptr<MWAWList> theList;
 
     theList=m_parserState.m_listManager->getList(newListId);
     if (!theList) {
@@ -1096,13 +1117,14 @@ void MWAWTextListener::insertComment(MWAWSubDocumentPtr &subDocument)
 }
 
 void MWAWTextListener::insertTextBox
-(MWAWPosition const &pos, MWAWSubDocumentPtr subDocument, MWAWGraphicStyle const &frameStyle)
+(MWAWPosition const &pos, MWAWSubDocumentPtr const &subDocument, MWAWGraphicStyle const &frameStyle)
 {
   if (!openFrame(pos, frameStyle)) return;
 
   librevenge::RVNGPropertyList propList;
   if (!frameStyle.m_frameNextName.empty())
     propList.insert("librevenge:next-frame-name",frameStyle.m_frameNextName.c_str());
+  // todo check style.m_rotate and style.m_flip
   m_documentInterface->openTextBox(propList);
   handleSubDocument(subDocument, libmwaw::DOC_TEXT_BOX);
   m_documentInterface->closeTextBox();
@@ -1618,7 +1640,7 @@ void MWAWTextListener::_handleFrameParameters
 ///////////////////
 // subdocument
 ///////////////////
-void MWAWTextListener::handleSubDocument(MWAWSubDocumentPtr subDocument, libmwaw::SubDocumentType subDocumentType)
+void MWAWTextListener::handleSubDocument(MWAWSubDocumentPtr const &subDocument, libmwaw::SubDocumentType subDocumentType)
 {
   _pushParsingState();
   _startSubDocument();
@@ -1652,10 +1674,12 @@ void MWAWTextListener::handleSubDocument(MWAWSubDocumentPtr subDocument, libmwaw
 
   // Check whether the document is calling itself
   bool sendDoc = true;
-  for (size_t i = 0; i < m_ds->m_subDocuments.size(); i++) {
+  for (auto doc : m_ds->m_subDocuments) {
     if (!subDocument)
       break;
-    if (subDocument == m_ds->m_subDocuments[i]) {
+    if (!doc)
+      continue;
+    if (*subDocument == *doc) {
       MWAW_DEBUG_MSG(("MWAWTextListener::handleSubDocument: recursif call, stop...\n"));
       sendDoc = false;
       break;
@@ -1664,7 +1688,7 @@ void MWAWTextListener::handleSubDocument(MWAWSubDocumentPtr subDocument, libmwaw
   if (sendDoc) {
     if (subDocument) {
       m_ds->m_subDocuments.push_back(subDocument);
-      shared_ptr<MWAWListener> listen(this, MWAW_shared_ptr_noop_deleter<MWAWTextListener>());
+      std::shared_ptr<MWAWListener> listen(this, MWAW_shared_ptr_noop_deleter<MWAWTextListener>());
       try {
         subDocument->parse(listen, subDocumentType);
       }
@@ -1683,6 +1707,7 @@ void MWAWTextListener::handleSubDocument(MWAWSubDocumentPtr subDocument, libmwaw
     break;
   case libmwaw::DOC_HEADER_FOOTER:
     m_ds->m_isHeaderFooterStarted = false;
+    break;
   case libmwaw::DOC_NONE:
   case libmwaw::DOC_CHART:
   case libmwaw::DOC_CHART_ZONE:
@@ -1852,9 +1877,9 @@ void MWAWTextListener::closeTableCell()
 ///////////////////
 
 // ---------- state stack ------------------
-shared_ptr<MWAWTextListenerInternal::State> MWAWTextListener::_pushParsingState()
+std::shared_ptr<MWAWTextListenerInternal::State> MWAWTextListener::_pushParsingState()
 {
-  shared_ptr<MWAWTextListenerInternal::State> actual = m_ps;
+  auto actual = m_ps;
   m_psStack.push_back(actual);
   m_ps.reset(new MWAWTextListenerInternal::State);
 
