@@ -354,13 +354,13 @@ bool MacDocParser::sendContents()
 // font
 bool MacDocParser::readFont(MWAWEntry const &entry)
 {
-  if (entry.length()<12) {
+  MWAWInputStreamPtr input = rsrcInput();
+  if (entry.length()<12 || !input || !input->checkPosition(entry.end())) {
     MWAW_DEBUG_MSG(("MacDocParser::readFont: the entry seems bad\n"));
     return false;
   }
 
   entry.setParsed(true);
-  MWAWInputStreamPtr input = rsrcInput();
   input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
   libmwaw::DebugFile &ascFile = rsrcAscii();
   libmwaw::DebugStream f;
