@@ -61,9 +61,22 @@ struct Shape {
   enum Type { Basic, Bitmap, Group, GroupEnd, Text, Unknown };
 
   //! constructor
-  Shape() : m_type(Unknown), m_box(), m_style(), m_shape(), m_id(-1), m_nextId(-1),
-    m_font(), m_paragraph(), m_textEntry(), m_childList(),
-    m_numBytesByRow(0), m_bitmapDim(), m_bitmapFileDim(), m_bitmapEntry(), m_isSent(false)
+  Shape()
+    : m_type(Unknown)
+    , m_box()
+    , m_style()
+    , m_shape()
+    , m_id(-1)
+    , m_nextId(-1)
+    , m_font()
+    , m_paragraph()
+    , m_textEntry()
+    , m_childList()
+    , m_numBytesByRow(0)
+    , m_bitmapDim()
+    , m_bitmapFileDim()
+    , m_bitmapEntry()
+    , m_isSent(false)
   {
   }
 
@@ -108,7 +121,10 @@ struct Shape {
 //! Internal: the state of a MacDrawParser
 struct State {
   //! constructor
-  State() : m_version(0), m_patternList(), m_shapeList()
+  State()
+    : m_version(0)
+    , m_patternList()
+    , m_shapeList()
   {
   }
   //! returns a pattern if posible
@@ -136,7 +152,7 @@ void State::initPatterns()
 {
   if (!m_patternList.empty()) return;
   for (int i=0; i<35; ++i) {
-    static uint16_t const(patterns0[]) = {
+    static uint16_t const patterns0[] = {
       0x0000,0x0000,0x0000,0x0000, 0xffff,0xffff,0xffff,0xffff,
       0xbbee,0xbbee,0xbbee,0xbbee, 0x55aa,0x55aa,0x55aa,0x55aa,
       0x8822,0x8822,0x8822,0x8822, 0x8800,0x2200,0x8800,0x2200,
@@ -156,7 +172,7 @@ void State::initPatterns()
       0x0a11,0xa040,0x00b1,0x4a4a, 0x4040,0x40ff,0x4040,0x4040,
       0x4122,0x1408,0x1422,0x4180
     };
-    static uint16_t const(patterns1[]) = {
+    static uint16_t const patterns1[] = {
       0x0000, 0x0000, 0x0000, 0x0000, 0xffff, 0xffff, 0xffff, 0xffff,
       0x77dd, 0x77dd, 0x77dd, 0x77dd, 0xaa55, 0xaa55, 0xaa55, 0xaa55,
       0x8822, 0x8822, 0x8822, 0x8822, 0x8800, 0x2200, 0x8800, 0x2200,
@@ -194,38 +210,37 @@ void State::initPatterns()
 
 ////////////////////////////////////////
 //! Internal: the subdocument of a MacDrawParser
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
-  SubDocument(MacDrawParser &pars, MWAWInputStreamPtr input, int zoneId) : MWAWSubDocument(&pars, input, MWAWEntry()), m_id(zoneId) {}
+  SubDocument(MacDrawParser &pars, MWAWInputStreamPtr const &input, int zoneId)
+    : MWAWSubDocument(&pars, input, MWAWEntry())
+    , m_id(zoneId)
+  {
+  }
 
   //! destructor
-  virtual ~SubDocument() {}
+  ~SubDocument() final {}
 
   //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const
+  bool operator!=(MWAWSubDocument const &doc) const final
   {
     if (MWAWSubDocument::operator!=(doc)) return true;
-    SubDocument const *sDoc = dynamic_cast<SubDocument const *>(&doc);
+    auto const *sDoc = dynamic_cast<SubDocument const *>(&doc);
     if (!sDoc) return true;
     if (m_id != sDoc->m_id) return true;
     return false;
   }
 
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
-  {
-    return !operator!=(doc);
-  }
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
 protected:
   //! the subdocument id
   int m_id;
 private:
-  SubDocument(SubDocument const &orig);
-  SubDocument &operator=(SubDocument const &orig);
+  SubDocument(SubDocument const &orig) = delete;
+  SubDocument &operator=(SubDocument const &orig) = delete;
 };
 
 void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType)
@@ -234,7 +249,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType)
     MWAW_DEBUG_MSG(("MacDrawParserInternal::SubDocument::parse: no listener\n"));
     return;
   }
-  MacDrawParser *parser=dynamic_cast<MacDrawParser *>(m_parser);
+  auto *parser=dynamic_cast<MacDrawParser *>(m_parser);
   if (!parser) {
     MWAW_DEBUG_MSG(("MacDrawParserInternal::SubDocument::parse: no parser\n"));
     return;
@@ -244,14 +259,14 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType)
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
 }
 
-
 }
 
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-MacDrawParser::MacDrawParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWGraphicParser(input, rsrcParser, header), m_state()
+MacDrawParser::MacDrawParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWGraphicParser(input, rsrcParser, header)
+  , m_state()
 {
   init();
 }
@@ -275,16 +290,17 @@ void MacDrawParser::init()
 ////////////////////////////////////////////////////////////
 void MacDrawParser::parse(librevenge::RVNGDrawingInterface *docInterface)
 {
-  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = false;
   try {
     // create the asciiFile
     ascii().setStream(getInput());
     ascii().open(asciiName());
-    checkHeader(0L);
+    checkHeader(nullptr);
     ok = createZones();
     if (ok) {
       createDocument(docInterface);
+      // reimplementme, ie. if the link chain is breaked, we will loose some shape
       for (size_t i=0; i<m_state->m_shapeList.size(); ++i) {
         MacDrawParserInternal::Shape const &shape=m_state->m_shapeList[i];
         if (shape.m_isSent) continue;
@@ -368,10 +384,10 @@ int MacDrawParser::readObject()
   }
   size_t shapeId= m_state->m_shapeList.size();
   m_state->m_shapeList.push_back(MacDrawParserInternal::Shape());
-  MacDrawParserInternal::Shape &shape=m_state->m_shapeList.back();
+  auto &shape=m_state->m_shapeList.back();
   shape.m_id=int(shapeId);
   shape.m_nextId=shape.m_id+1; // default value
-  int type=static_cast<int>(input->readULong(1));
+  auto type=static_cast<int>(input->readULong(1));
   switch (type) {
   case 0:
     shape.m_type=MacDrawParserInternal::Shape::GroupEnd;
@@ -437,15 +453,15 @@ int MacDrawParser::readObject()
     m_state->m_shapeList.pop_back();
     return -1;
   }
-  int val=static_cast<int>(input->readULong(1));
+  auto val=static_cast<int>(input->readULong(1));
   if (val==1) f << "locked,";
   else if (val) f << "#lock=" << val << ",";
   val=static_cast<int>(input->readLong(2));
   if (val) f << "f0=" << val << ",";
 
-  int lineType=static_cast<int>(input->readULong(1));
+  auto lineType=static_cast<int>(input->readULong(1));
   if (lineType>=1 && lineType<6) {
-    static float const(widths[]) = { 0, 1, 2, 3.5f, 5 };
+    static float const widths[] = { 0, 1, 2, 3.5f, 5 };
     shape.m_style.m_lineWidth=widths[lineType-1];
     if (lineType!=2) // default
       f << "line[width]=" << widths[lineType-1] << ",";
@@ -454,7 +470,7 @@ int MacDrawParser::readObject()
     MWAW_DEBUG_MSG(("MacDrawParser::readObject: find unexpected line type\n"));
     f << "#line[width]=" << lineType << ",";
   }
-  int linePat=static_cast<int>(input->readULong(1));
+  auto linePat=static_cast<int>(input->readULong(1));
   if (linePat>=1&&linePat<37) {
     if (linePat==1)
       shape.m_style.m_lineWidth=0; // no pattern
@@ -471,7 +487,7 @@ int MacDrawParser::readObject()
     MWAW_DEBUG_MSG(("MacDrawParser::readObject: find unexpected line pattern\n"));
     f << "#line[pat]=" << linePat << ",";
   }
-  int surfPat=static_cast<int>(input->readULong(1));
+  auto surfPat=static_cast<int>(input->readULong(1));
   if (surfPat>=1&&surfPat<37) {
     if (surfPat!=1) {
       f << "surf[pat]=" << surfPat << ",";
@@ -528,11 +544,11 @@ int MacDrawParser::readObject()
       ok=false;
       break;
     }
-    long id=long(input->readULong(4));
+    auto id=long(input->readULong(4));
     if (id) f << "id=" << std::hex << id << std::dec << ",";
 
     MWAWFont &font=shape.m_font;
-    int flag = static_cast<int>(input->readULong(1));
+    auto flag = static_cast<int>(input->readULong(1));
     uint32_t flags=0;
     if (flag&0x1) flags |= MWAWFont::boldBit;
     if (flag&0x2) flags |= MWAWFont::italicBit;
@@ -544,7 +560,7 @@ int MacDrawParser::readObject()
     if (flag&0x80) f << "#flag0[0x80],";
     font.setFlags(flags);
     font.setId(static_cast<int>(input->readULong(1)));
-    int fSz=static_cast<int>(input->readULong(1));
+    auto fSz=static_cast<int>(input->readULong(1));
     if (fSz>=1 && fSz<9) {
       static int const fontSize[]= {9,10,12,14,18,24,36,48};
       font.setSize(float(fontSize[fSz-1]));
@@ -601,7 +617,7 @@ int MacDrawParser::readObject()
       f << "sym,";
     }
     if (val&0xF8) f << "#rot=" << std::hex << (val&0xF8) << std::dec << ",";
-    int N=static_cast<int>(input->readULong(2));
+    auto N=static_cast<int>(input->readULong(2));
     if (!input->checkPosition(actPos+20+N)) {
       MWAW_DEBUG_MSG(("MacDrawParser::readObject: the number of character seems bad\n"));
       f << "##N=" << N << ",";
@@ -609,7 +625,7 @@ int MacDrawParser::readObject()
       break;
     }
     float dim[4];
-    for (int i=0; i<4; ++i) dim[i]=float(input->readLong(2));
+    for (auto &d : dim) d=float(input->readLong(2));
     shape.m_box=MWAWBox2f(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
     shape.m_textEntry.setBegin(input->tell());
     shape.m_textEntry.setLength(N);
@@ -631,7 +647,7 @@ int MacDrawParser::readObject()
       break;
     }
     float dim[4];
-    for (int i=0; i<4; ++i) dim[i]=float(input->readLong(4))/65536.f;
+    for (auto &d : dim) d=float(input->readLong(4))/65536.f;
     MWAWBox2f box(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
     f << box << ",";
     shape.m_box=box;
@@ -649,7 +665,7 @@ int MacDrawParser::readObject()
       break;
     case 7: {
       int fileAngle[2];
-      for (int i=0; i<2; ++i) fileAngle[i]=static_cast<int>(input->readLong(2));
+      for (auto &angle : fileAngle) angle=static_cast<int>(input->readLong(2));
       f << "angle=" << fileAngle[0] << "x" << fileAngle[0]+fileAngle[1] << ",";
 
       if (fileAngle[1]<0) {
@@ -709,17 +725,17 @@ int MacDrawParser::readObject()
   }
   case 8:
   case 9: {
-    long dSz=long(input->readULong(4));
+    auto dSz=long(input->readULong(4));
     if (dSz<18||!input->checkPosition(actPos+4+dSz)) {
       MWAW_DEBUG_MSG(("MacDrawParser::readObject: the polygon data size seems bad\n"));
       f << "###";
       ok=false;
       break;
     }
-    int N=static_cast<int>(input->readULong(2));
+    auto N=static_cast<int>(input->readULong(2));
     f << "N=" << N << ",";
     float dim[4];
-    for (int i=0; i<4; ++i) dim[i]=float(input->readLong(4))/65536.f;
+    for (auto &d : dim) d=float(input->readLong(4))/65536.f;
     MWAWBox2f box(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
     f << box << ",";
     shape.m_shape.m_type = MWAWGraphicShape::Polygon;
@@ -742,7 +758,7 @@ int MacDrawParser::readObject()
       f << "delta=[";
       for (int i=0; i<N-1; ++i) {
         int delta[2];
-        for (int j=0; j<2; ++j) delta[j]=static_cast<int>(input->readLong(1));
+        for (auto &d : delta) d=static_cast<int>(input->readLong(1));
         MWAWVec2f deltaPt(static_cast<float>(delta[0]), static_cast<float>(delta[1]));
         point+=deltaPt;
         vertices.push_back(point);
@@ -754,7 +770,7 @@ int MacDrawParser::readObject()
       f << "pts=[";
       for (int i=0; i<N; ++i) {
         float coord[2];
-        for (int j=0; j<2; ++j) coord[j]=float(input->readLong(4))/65536.f;
+        for (auto &c : coord) c=float(input->readLong(4))/65536.f;
         MWAWVec2f point(coord[1], coord[0]);
         f << point << ",";
         vertices.push_back(point);
@@ -774,12 +790,12 @@ int MacDrawParser::readObject()
     int const vers=version();
     if (vers==1) {
       float dim[4];
-      for (int i=0; i<4; ++i) dim[i]=float(input->readLong(4))/65536.f;
+      for (auto &d : dim) d=float(input->readLong(4))/65536.f;
       MWAWBox2f box(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
       f << box << ",";
       shape.m_box=box;
     }
-    int N=static_cast<int>(input->readULong(2));
+    auto N=static_cast<int>(input->readULong(2));
     f << "N=" << N << ",";
     val=static_cast<int>(input->readLong(2));
     if (val!=N) f << "N[child]=" << val << ",";
@@ -787,7 +803,7 @@ int MacDrawParser::readObject()
     f << "groupSize=" << std::hex << dSz << std::dec << ",";
     if (vers==0) {
       float dim[4];
-      for (int i=0; i<4; ++i) dim[i]=float(input->readLong(4))/65536.f;
+      for (auto &d : dim) d=float(input->readLong(4))/65536.f;
       MWAWBox2f box(MWAWVec2f(dim[1],dim[0]), MWAWVec2f(dim[3],dim[2]));
       f << box << ",";
       shape.m_box=box;
@@ -808,7 +824,7 @@ int MacDrawParser::readObject()
       m_state->m_shapeList[shapeId].m_childList.push_back(size_t(cId));
     }
     int cId=readObject(); // read end group
-    int nextId=int(m_state->m_shapeList.size());
+    auto nextId=int(m_state->m_shapeList.size());
     if (cId<0) {
       m_state->m_shapeList[shapeId].m_nextId=nextId;
       return int(shapeId);
@@ -835,12 +851,12 @@ int MacDrawParser::readObject()
       if (val) f << "f0=" << val << ",";
     }
     int dim[4];
-    for (int i=0; i<4; ++i) dim[i]=static_cast<int>(input->readLong(2));
+    for (auto &d : dim) d=static_cast<int>(input->readLong(2));
     MWAWBox2i &bitmapBox=shape.m_bitmapDim;
     bitmapBox=MWAWBox2i(MWAWVec2i(dim[1],dim[0]), MWAWVec2i(dim[3],dim[2]));
     f << "bitmap[dim]="<< bitmapBox << ",";
     float fDim[4];
-    for (int i=0; i<4; ++i) fDim[i]=float(input->readLong(4))/65536.f;
+    for (auto &d : fDim) d=float(input->readLong(4))/65536.f;
     MWAWBox2f box(MWAWVec2f(fDim[1],fDim[0]), MWAWVec2f(fDim[3],fDim[2]));
     f << box << ",";
     shape.m_box=box;
@@ -849,7 +865,7 @@ int MacDrawParser::readObject()
     if (val) f << "id=" << std::hex << val << std::dec << ",";
     shape.m_numBytesByRow=static_cast<int>(input->readULong(2));
 
-    for (int i=0; i<4; ++i) dim[i]=static_cast<int>(input->readLong(2));
+    for (auto &d : dim) d=static_cast<int>(input->readLong(2));
     MWAWBox2i &fileBox=shape.m_bitmapFileDim;
     fileBox=MWAWBox2i(MWAWVec2i(dim[1],dim[0]), MWAWVec2i(dim[3],dim[2]));
     f << "bitmap[dimInFile]="<< fileBox << ",";
@@ -897,7 +913,7 @@ bool MacDrawParser::checkHeader(MWAWHeader *header, bool strict)
   libmwaw::DebugStream f;
   f << "FileHeader:";
   input->seek(0, librevenge::RVNG_SEEK_SET);
-  int val=static_cast<int>(input->readULong(2));
+  auto val=static_cast<int>(input->readULong(2));
   int vers=0;
   if (val==0x4452) {
     if (input->readULong(2)!=0x5747) return false;
@@ -934,7 +950,7 @@ bool MacDrawParser::checkHeader(MWAWHeader *header, bool strict)
     // we must check that this is not a basic pict file
     input->seek(512+2, librevenge::RVNG_SEEK_SET);
     int dim[4];
-    for (int i=0; i<4; ++i) dim[i]=static_cast<int>(input->readLong(2));
+    for (auto &d : dim) d=static_cast<int>(input->readLong(2));
     val=static_cast<int>(input->readLong(2));
     if (dim[0]<dim[2] && dim[1]<dim[3] && (val==0x1101 || (val==0x11 && input->readLong(2)==0x2ff))) {
       // posible
@@ -988,7 +1004,7 @@ bool MacDrawParser::readPrefs()
   libmwaw::DebugStream f;
   f << "Entries(Prefs):";
   for (int i=0; i<9; ++i) { // f0=1|2|7, f1=0|75|78|7c, f2=0|48, f4=0|48, f5=0|48, f6=0|48, f7=0|48
-    int val=static_cast<int>(input->readLong(2));
+    auto val=static_cast<int>(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   ascii().addDelimiter(input->tell(),'|');
@@ -1102,12 +1118,12 @@ bool MacDrawParser::send(MacDrawParserInternal::Shape const &shape)
     size_t numShapes=m_state->m_shapeList.size();
     if (!numShapes) break;
     listener->openGroup(pos);
-    for (size_t i=0; i<shape.m_childList.size(); ++i) {
-      if (shape.m_childList[i]>=numShapes) {
+    for (auto id : shape.m_childList) {
+      if (id>=numShapes) {
         MWAW_DEBUG_MSG(("MacDrawParser::send: can not find a child\n"));
         continue;
       }
-      MacDrawParserInternal::Shape const &child=m_state->m_shapeList[shape.m_childList[i]];
+      MacDrawParserInternal::Shape const &child=m_state->m_shapeList[id];
       if (child.m_isSent) {
         MWAW_DEBUG_MSG(("MacDrawParser::send: the child is already sent\n"));
         continue;
@@ -1120,7 +1136,7 @@ bool MacDrawParser::send(MacDrawParserInternal::Shape const &shape)
   case MacDrawParserInternal::Shape::GroupEnd:
     break;
   case MacDrawParserInternal::Shape::Text: {
-    shared_ptr<MWAWSubDocument> doc(new MacDrawParserInternal::SubDocument(*this, getInput(), shape.m_id));
+    std::shared_ptr<MWAWSubDocument> doc(new MacDrawParserInternal::SubDocument(*this, getInput(), shape.m_id));
     listener->insertTextBox(pos, doc, shape.m_style);
     return true;
   }
@@ -1142,9 +1158,11 @@ bool MacDrawParser::sendBitmap(MacDrawParserInternal::Shape const &shape, MWAWPo
   }
   if (!shape.m_bitmapEntry.valid()) return false;
   int const numBytesByRow=shape.m_numBytesByRow;
+  MWAWInputStreamPtr input=getInput();
   MWAWVec2i pictDim=shape.m_bitmapDim.size();
   if (shape.m_type!=MacDrawParserInternal::Shape::Bitmap || numBytesByRow<=0 ||
       pictDim[0]<0 || pictDim[1]<0 ||
+      shape.m_bitmapEntry.length() > (input->size() - shape.m_bitmapEntry.begin()) ||
       shape.m_bitmapFileDim.size()[1]<shape.m_bitmapEntry.length() / numBytesByRow ||
       shape.m_bitmapDim[0][0]<0 || shape.m_bitmapDim[0][1]<0 ||
       shape.m_bitmapDim[0][0]<shape.m_bitmapFileDim[0][0] ||
@@ -1163,7 +1181,6 @@ bool MacDrawParser::sendBitmap(MacDrawParserInternal::Shape const &shape, MWAWPo
   for (int r=shape.m_bitmapDim[0][1]; r<shape.m_bitmapFileDim[0][1]; ++r) pict.setRow(r-shape.m_bitmapDim[0][1], &data[0]);
   for (int r=shape.m_bitmapFileDim[1][1]; r<shape.m_bitmapDim[1][1]; ++r) pict.setRow(r-shape.m_bitmapDim[0][1], &data[0]);
 
-  MWAWInputStreamPtr input=getInput();
   input->seek(shape.m_bitmapEntry.begin(), librevenge::RVNG_SEEK_SET);
   for (int r=shape.m_bitmapFileDim[0][1]; r<shape.m_bitmapFileDim[1][1] && !input->isEnd(); ++r) {
     long pos=input->tell();
@@ -1173,7 +1190,7 @@ bool MacDrawParser::sendBitmap(MacDrawParserInternal::Shape const &shape, MWAWPo
     }
     int wPos=shape.m_bitmapDim[0][0]-shape.m_bitmapFileDim[0][0];
     for (int col=shape.m_bitmapFileDim[0][0]; col<shape.m_bitmapFileDim[1][0]; ++col) {
-      unsigned char c=static_cast<unsigned char>(input->readULong(1));
+      auto c=static_cast<unsigned char>(input->readULong(1));
       for (int j=0, bit=0x80; j<8 ; ++j, bit>>=1) {
         if (wPos>=pictDim[0]) break;
         data[size_t(wPos++)]=(c&bit) ? black : transparent;
@@ -1227,7 +1244,7 @@ bool MacDrawParser::sendText(int zId)
   while (!input->isEnd()) {
     if (input->tell()>=shape.m_textEntry.end())
       break;
-    char c = char(input->readULong(1));
+    auto c = char(input->readULong(1));
     if (c==0) {
       MWAW_DEBUG_MSG(("MacDrawParser::sendText: find char 0\n"));
       f << "#[0]";
