@@ -62,7 +62,10 @@ namespace MindWrtParserInternal
 //! Internal: a field of a MindWrtParser
 struct Field {
   //! constructor
-  Field(MWAWField::Type type=MWAWField::None) : m_type(type), m_pos(0,-1), m_extra("")
+  explicit Field(MWAWField::Type type=MWAWField::None)
+    : m_type(type)
+    , m_pos(0,-1)
+    , m_extra("")
   {
   }
   //! return true is the field is defined
@@ -100,9 +103,13 @@ struct Field {
       o << "title,";
       break;
     case MWAWField::None:
+    case MWAWField::BookmarkStart:
+    case MWAWField::BookmarkEnd:
     case MWAWField::PageCount:
     case MWAWField::Database:
+#if !defined(__clang__)
     default:
+#endif
       MWAW_DEBUG_MSG(("MindWrtParserInternal::Field: unexpected field type %d\n", int(field.m_type)));
       break;
     }
@@ -122,8 +129,14 @@ struct Field {
 //! Internal: the list properties of a MindWrtParser
 struct ListProperties {
   //! constructor
-  ListProperties() : m_startListIndex(1), m_headingStyle(1), m_headingFullSubLevels(true),
-    m_headingListLevels(), m_listLevelsRepeatPos(1), m_showFirstLevel(false), m_useHeadingStyle(false)
+  ListProperties()
+    : m_startListIndex(1)
+    , m_headingStyle(1)
+    , m_headingFullSubLevels(true)
+    , m_headingListLevels()
+    , m_listLevelsRepeatPos(1)
+    , m_showFirstLevel(false)
+    , m_useHeadingStyle(false)
   {
   }
   //! updates the heading list
@@ -148,7 +161,7 @@ struct ListProperties {
 
 MWAWListLevel ListProperties::getLevel(int level) const
 {
-  int numLevels=int(m_headingListLevels.size());
+  auto numLevels=int(m_headingListLevels.size());
   if (level < 0 || numLevels <= 0) {
     MWAW_DEBUG_MSG(("ListProperties::updateHeadingList: can not find any level\n"));
     return MWAWListLevel();
@@ -241,10 +254,20 @@ void  ListProperties::updateHeadingList()
 ////////////////////////////////////////
 //! Internal: a line information of a MindWrtParser
 struct LineInfo {
-  LineInfo() : m_entry(), m_type(-1000), m_height(0), m_y(-1), m_page(-1),
-    m_paragraph(),  m_specialHeadingInterface(false), m_paragraphSet(false), m_listLevel(0), m_listType(0), m_extra("")
+  LineInfo()
+    : m_entry()
+    , m_type(-1000)
+    , m_height(0)
+    , m_y(-1)
+    , m_page(-1)
+    , m_paragraph()
+    , m_specialHeadingInterface(false)
+    , m_paragraphSet(false)
+    , m_listLevel(0)
+    , m_listType(0)
+    , m_extra("")
   {
-    for (int i = 0; i < 4; i++) m_flags[i] = 0;
+    for (auto &fl : m_flags) fl=0;
   }
 
   //! operator<<
@@ -358,7 +381,8 @@ struct LineInfo {
 ////////////////////////////////////////
 //! Internal: a zone information of a MindWrtParser
 struct ZoneInfo {
-  ZoneInfo() : m_linesList()
+  ZoneInfo()
+    : m_linesList()
   {
   }
 
@@ -371,7 +395,6 @@ struct ZoneInfo {
 
 void ZoneInfo::updateListId(ListProperties &prop, MWAWListManager &listManager)
 {
-  size_t numLines=m_linesList.size();
   bool headingStyle=prop.m_useHeadingStyle && prop.m_headingStyle>=1 && prop.m_headingStyle<=4;
 
   /* we have 4 list, we are almost independent: heading, unlabelled, decimal, bullet */
@@ -381,11 +404,10 @@ void ZoneInfo::updateListId(ListProperties &prop, MWAWListManager &listManager)
   levelsList[3].m_type = MWAWListLevel::BULLET;
   libmwaw::appendUnicode(0x2022, levelsList[3].m_bullet);
 
-  shared_ptr<MWAWList> listsList[4];
+  std::shared_ptr<MWAWList> listsList[4];
   int maxLevelSet=0;
 
-  for (size_t i = 0; i < numLines; i++) {
-    LineInfo &line = m_linesList[i];
+  for (auto &line : m_linesList) {
     if (line.m_height == 0 ||  // ruler or false graphic
         (line.m_type==-1 && line.m_entry.length()==0)) continue;
     MWAWParagraph &para = line.m_paragraph;
@@ -446,11 +468,11 @@ void ZoneInfo::updateListId(ListProperties &prop, MWAWListManager &listManager)
     else
       *(para.m_margins[0])=-0.2;
 
-    shared_ptr<MWAWList> &actList=listsList[line.m_listType];
+    auto &actList=listsList[line.m_listType];
     if (!actList) // we have a pb....
       continue;
-    for (int type=0; type<4; type++)
-      if (listsList[type]) listsList[type]->setLevel(level);
+    for (auto &type : listsList)
+      if (type) type->setLevel(level);
     if (line.m_listType==0)
       listsList[2]->setStartValueForNextElement(level==1 ? prop.m_startListIndex : 1);
 
@@ -465,12 +487,16 @@ void ZoneInfo::updateListId(ListProperties &prop, MWAWListManager &listManager)
 //! Internal: the state of a MindWrtParser
 struct State {
   //! constructor
-  State() : m_compressCorr(" etnroaisdlhcfp"), m_entryMap(), m_listProperties(),
-    m_actPage(0), m_numPages(0), m_headerHeight(0), m_footerHeight(0),
-    m_headerFieldList(), m_footerFieldList()
+  State()
+    : m_compressCorr(" etnroaisdlhcfp")
+    , m_entryMap()
+    , m_listProperties()
+    , m_actPage(0)
+    , m_numPages(0)
+    , m_headerFieldList()
+    , m_footerFieldList()
   {
-    for (int i = 0; i < 3; i++)
-      m_numLinesByZone[i] = 0;
+    for (auto &num : m_numLinesByZone) num = 0;
   }
 
   //! the correspondance between int compressed and char : must be 15 character
@@ -488,8 +514,6 @@ struct State {
   ListProperties m_listProperties;
   int m_actPage /** the actual page */, m_numPages /** the number of page of the final document */;
   //! the actual list id
-  int m_headerHeight /** the header height if known */,
-      m_footerHeight /** the footer height if known */;
   //! the header field list
   std::vector<Field> m_headerFieldList;
   //! the footer field list
@@ -498,34 +522,32 @@ struct State {
 
 ////////////////////////////////////////
 //! Internal: the subdocument of a MindWrtParser
-class SubDocument : public MWAWSubDocument
+class SubDocument final : public MWAWSubDocument
 {
 public:
-  SubDocument(MindWrtParser &pars, MWAWInputStreamPtr input, int zoneId, int step) :
-    MWAWSubDocument(&pars, input, MWAWEntry()), m_id(zoneId), m_step(step) {}
+  SubDocument(MindWrtParser &pars, MWAWInputStreamPtr const &input, int zoneId, int step)
+    : MWAWSubDocument(&pars, input, MWAWEntry())
+    , m_id(zoneId)
+    , m_step(step)
+  {
+  }
 
   //! destructor
-  virtual ~SubDocument() {}
+  ~SubDocument() final {}
 
   //! operator!=
-  virtual bool operator!=(MWAWSubDocument const &doc) const
+  bool operator!=(MWAWSubDocument const &doc) const final
   {
     if (MWAWSubDocument::operator!=(doc)) return true;
-    SubDocument const *sDoc = dynamic_cast<SubDocument const *>(&doc);
+    auto const *sDoc = dynamic_cast<SubDocument const *>(&doc);
     if (!sDoc) return true;
     if (m_id != sDoc->m_id) return true;
     if (m_step != sDoc->m_step) return true;
     return false;
   }
 
-  //! operator!==
-  virtual bool operator==(MWAWSubDocument const &doc) const
-  {
-    return !operator!=(doc);
-  }
-
   //! the parser function
-  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type);
+  void parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type) final;
 
 protected:
   //! the subdocument id
@@ -548,7 +570,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
     MWAW_DEBUG_MSG(("MindWrtParserInternal::SubDocument::parse: unknown step\n"));
     return;
   }
-  MindWrtParser *parser=dynamic_cast<MindWrtParser *>(m_parser);
+  auto *parser=dynamic_cast<MindWrtParser *>(m_parser);
   if (!parser) {
     MWAW_DEBUG_MSG(("MindWrtParserInternal::SubDocument::parse: no parser\n"));
     return;
@@ -565,8 +587,9 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-MindWrtParser::MindWrtParser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWTextParser(input, rsrcParser, header), m_state()
+MindWrtParser::MindWrtParser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWTextParser(input, rsrcParser, header)
+  , m_state()
 {
   init();
 }
@@ -606,8 +629,8 @@ MWAWEntry MindWrtParser::readEntry()
 {
   MWAWEntry res;
   MWAWInputStreamPtr input = getInput();
-  res.setBegin((long) input->readULong(4));
-  res.setLength((long) input->readULong(4));
+  res.setBegin(long(input->readULong(4)));
+  res.setLength(long(input->readULong(4)));
   if (res.length() && !input->checkPosition(res.end())) {
     MWAW_DEBUG_MSG(("MindWrtParser::readEntry: find an invalid entry\n"));
     res.setLength(0);
@@ -619,14 +642,14 @@ MWAWEntry MindWrtParser::readEntry()
 ////////////////////////////////////////////////////////////
 void MindWrtParser::parse(librevenge::RVNGTextInterface *docInterface)
 {
-  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = true;
   try {
     // create the asciiFile
     ascii().setStream(getInput());
     ascii().open(asciiName());
 
-    checkHeader(0L);
+    checkHeader(nullptr);
     if (getRSRCParser()) {
       MWAWEntry corrEntry = getRSRCParser()->getEntry("STR ", 700);
       std::string corrString("");
@@ -645,10 +668,8 @@ void MindWrtParser::parse(librevenge::RVNGTextInterface *docInterface)
     }
 
     libmwaw::DebugStream f;
-    std::multimap<std::string, MWAWEntry>::const_iterator it
-      = m_state->m_entryMap.begin();
-    while (it != m_state->m_entryMap.end()) {
-      MWAWEntry const &entry = (it++)->second;
+    for (auto it : m_state->m_entryMap) {
+      MWAWEntry const &entry = it.second;
       if (entry.isParsed())
         continue;
       f.str("");
@@ -684,8 +705,7 @@ void MindWrtParser::createDocument(librevenge::RVNGTextInterface *documentInterf
   m_state->m_actPage = 0;
 
   int numPage = 0, numBreakPage = 0;
-  for (size_t i = 0; i < m_state->m_zones[0].m_linesList.size(); i++) {
-    MindWrtParserInternal::LineInfo const &line = m_state->m_zones[0].m_linesList[i];
+  for (auto const &line : m_state->m_zones[0].m_linesList) {
     if (line.m_type == -2)
       numBreakPage++;
     if (line.m_page > numPage)
@@ -697,7 +717,7 @@ void MindWrtParser::createDocument(librevenge::RVNGTextInterface *documentInterf
   // create the page list
   MWAWPageSpan ps(getPageSpan());
   for (int i = 1; i <= 2; i++) {
-    if (!m_state->m_zones[i].m_linesList.size())
+    if (m_state->m_zones[i].m_linesList.empty())
       continue;
     MWAWHeaderFooter hF((i==1) ? MWAWHeaderFooter::HEADER : MWAWHeaderFooter::FOOTER, MWAWHeaderFooter::ALL);
     hF.m_subDocument.reset(new MindWrtParserInternal::SubDocument(*this, getInput(), i, 0));
@@ -785,9 +805,8 @@ bool MindWrtParser::createZones()
   ascii().addPos(pos);
   ascii().addNote(f.str().c_str());
 
-  std::multimap<std::string, MWAWEntry>::iterator it;
   // first read print info
-  it = m_state->m_entryMap.find("PrintInfo");
+  auto it = m_state->m_entryMap.find("PrintInfo");
   if (it !=  m_state->m_entryMap.end())
     readPrintInfo(it->second);
   // now the heading properties
@@ -818,8 +837,8 @@ bool MindWrtParser::createZones()
   while (it !=  m_state->m_entryMap.end() && it->first == "LineInfo")
     readLinesInfo(it++->second);
 
-  for (int i = 0; i < 3; i++)
-    if (m_state->m_zones[i].m_linesList.size())
+  for (auto const &info : m_state->m_zones)
+    if (info.m_linesList.size())
       return true;
   return false;
 }
@@ -858,9 +877,9 @@ bool MindWrtParser::sendZone(int id)
   MWAWInputStreamPtr input = getInput();
   libmwaw::DebugStream f;
   if (id==0) m_state->m_actPage = 1;
-  MindWrtParserInternal::ZoneInfo &zone = m_state->m_zones[id];
+  auto &zone = m_state->m_zones[id];
   for (size_t i = 0; i < zone.m_linesList.size(); i++) {
-    MindWrtParserInternal::LineInfo &line = zone.m_linesList[i];
+    auto &line = zone.m_linesList[i];
     if (i==0) {
       ascii().addPos(line.m_entry.begin());
       ascii().addNote("Entries(Text)");
@@ -927,7 +946,7 @@ bool MindWrtParser::readGraphic(MindWrtParserInternal::LineInfo const &line)
 
   MWAWInputStreamPtr input = getInput();
   libmwaw::DebugStream f;
-  int sz = (int) line.m_entry.length();
+  auto sz = static_cast<int>(line.m_entry.length());
   if (sz < 10) {
     MWAW_DEBUG_MSG(("MindWrtParser::readGraphic: zone size is two short or odd\n"));
     return false;
@@ -937,12 +956,12 @@ bool MindWrtParser::readGraphic(MindWrtParserInternal::LineInfo const &line)
   input->seek(pos, librevenge::RVNG_SEEK_SET);
 
   int dim[4];
-  for (int i = 0; i < 4; i++) dim[i] = (int) input->readLong(2);
-  MWAWBox2f box(MWAWVec2f((float)dim[1],(float)dim[0]),
-                MWAWVec2f((float)dim[3],(float)dim[2]));
+  for (auto &d : dim) d = static_cast<int>(input->readLong(2));
+  MWAWBox2f box(MWAWVec2f(static_cast<float>(dim[1]),static_cast<float>(dim[0])),
+                MWAWVec2f(static_cast<float>(dim[3]),static_cast<float>(dim[2])));
   f << "Entries(graphic): bdBox=" << box << ",";
 
-  shared_ptr<MWAWPict> pict(MWAWPictData::get(input, sz-8));
+  std::shared_ptr<MWAWPict> pict(MWAWPictData::get(input, sz-8));
   if (!pict) {
     MWAW_DEBUG_MSG(("MindWrtParser::readGraphic: can not read the picture\n"));
     return false;
@@ -968,7 +987,7 @@ bool MindWrtParser::readRuler(MindWrtParserInternal::LineInfo &line)
   MWAWInputStreamPtr input = getInput();
   libmwaw::DebugStream f;
 
-  if (line.m_entry.length() < 10 || (line.m_entry.length()%2)) {
+  if (line.m_entry.length() < 10 || (line.m_entry.length()%2) || !input->checkPosition(line.m_entry.end())) {
     MWAW_DEBUG_MSG(("MindWrtParser::readRuler: zone size is two short or odd\n"));
     return false;
   }
@@ -979,13 +998,13 @@ bool MindWrtParser::readRuler(MindWrtParserInternal::LineInfo &line)
 
   MWAWParagraph para;
   para.m_marginsUnit = librevenge::RVNG_POINT;
-  para.m_margins[1] = (double) input->readULong(2);
-  para.m_margins[2] = getPageWidth()*72.0-(double) input->readULong(2);
+  para.m_margins[1] = double(input->readULong(2));
+  para.m_margins[2] = getPageWidth()*72.0-double(input->readULong(2));
   if (*(para.m_margins[2]) < 0) {
     f << "#rightMargin=" << getPageWidth()*72.0-*(para.m_margins[2]);
     para.m_margins[2] = 0.0;
   }
-  long val = (long) input->readULong(1);
+  auto val = long(input->readULong(1));
   switch (val) {
   case 0:
     para.m_justify = MWAWParagraph::JustificationLeft;
@@ -1003,14 +1022,14 @@ bool MindWrtParser::readRuler(MindWrtParserInternal::LineInfo &line)
     f << "#align=" << std::hex << val << std::dec << ",";
     break;
   }
-  int N = (int) input->readULong(1);
+  auto N = static_cast<int>(input->readULong(1));
   if (line.m_entry.length() != 2*N+10) {
     MWAW_DEBUG_MSG(("MindWrtParser::readRuler: num tabs is incorrect\n"));
     line.m_paragraph = para;
     line.m_paragraphSet = true;
     return false;
   }
-  val = (long) input->readULong(2);
+  val = long(input->readULong(2));
   double factor = 1.0;
   switch (val & 0x7FFF) {
   case 0:
@@ -1030,7 +1049,7 @@ bool MindWrtParser::readRuler(MindWrtParserInternal::LineInfo &line)
   }
   else
     para.setInterline(factor, librevenge::RVNG_PERCENT);
-  para.m_margins[0] = ((double) input->readULong(2))-*(para.m_margins[1]);
+  para.m_margins[0] = double(input->readULong(2))-*(para.m_margins[1]);
   for (int i = 0; i < N; i++) {
     MWAWTabStop tab;
     val = input->readLong(2);
@@ -1065,15 +1084,14 @@ void MindWrtParser::sendHeaderFooter(bool header)
     return;
   }
   int zId=header ? 1 : 2;
-  std::vector<MindWrtParserInternal::Field> const &fieldList=
-    header ? m_state->m_headerFieldList : m_state->m_footerFieldList;
-  if (fieldList.size()) {
+  auto const &fieldList= header ? m_state->m_headerFieldList : m_state->m_footerFieldList;
+  if (!fieldList.empty()) {
     /** field are separated from the main text
         -> we need to use an intermediate frame */
     MWAWPosition fPos(MWAWVec2f(0,0), MWAWVec2f(float(getPageWidth()),0), librevenge::RVNG_INCH);
     fPos.m_anchorTo = MWAWPosition::Paragraph;
     fPos.m_wrapping =  MWAWPosition::WBackground;
-    shared_ptr<MindWrtParserInternal::SubDocument> subDoc
+    std::shared_ptr<MindWrtParserInternal::SubDocument> subDoc
     (new MindWrtParserInternal::SubDocument(*this, getInput(), zId, 1));
     listener->insertTextBox(fPos, subDoc);
   }
@@ -1087,8 +1105,7 @@ void MindWrtParser::sendHeaderFooterFields(bool header)
     MWAW_DEBUG_MSG(("MindWrtParser::sendHeaderFooterFields: can note find the listener\n"));
     return;
   }
-  std::vector<MindWrtParserInternal::Field> fieldList=
-    header ? m_state->m_headerFieldList : m_state->m_footerFieldList;
+  auto fieldList=header ? m_state->m_headerFieldList : m_state->m_footerFieldList;
   size_t numFields=fieldList.size();
   if (!numFields) {
     MWAW_DEBUG_MSG(("MindWrtParser::sendHeaderFooterFields: called with empty field list\n"));
@@ -1101,9 +1118,7 @@ void MindWrtParser::sendHeaderFooterFields(bool header)
       if (diffLine > 0 ||
           (diffLine==0 && fieldList[j].m_pos[0]>fieldList[i].m_pos[0]))
         continue;
-      MindWrtParserInternal::Field tmp=fieldList[j];
-      fieldList[j]=fieldList[i];
-      fieldList[i]=tmp;
+      std::swap(fieldList[i], fieldList[j]);
     }
   }
   if (fieldList[numFields-1].m_pos[1]>10) {
@@ -1162,7 +1177,7 @@ bool MindWrtParser::readText(MindWrtParserInternal::LineInfo const &line)
   long pos=line.m_entry.begin();
   long endPos=line.m_entry.end();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  int num = (int) input->readULong(2);
+  auto num = static_cast<int>(input->readULong(2));
   if (pos+num >= endPos) {
     MWAW_DEBUG_MSG(("MindWrtParser::readText: numChar is too long\n"));
     return false;
@@ -1191,12 +1206,12 @@ bool MindWrtParser::readText(MindWrtParserInternal::LineInfo const &line)
   }
   std::string text("");
   for (int n = 0; n < num; n++) {
-    char c = (char) input->readULong(1);
+    auto c = char(input->readULong(1));
     if (!c) {
       MWAW_DEBUG_MSG(("MindWrtParser::readText: find 0 char\n"));
       continue;
     }
-    text+=(char) c;
+    text+=char(c);
   }
   f << text;
 
@@ -1229,7 +1244,7 @@ bool MindWrtParser::readCompressedText(MindWrtParserInternal::LineInfo const &li
   long pos=line.m_entry.begin();
   long endPos=line.m_entry.end();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
-  int num = (int) input->readULong(2);
+  auto num = static_cast<int>(input->readULong(2));
   if (pos+num/2 > endPos) {
     MWAW_DEBUG_MSG(("MindWrtParser::readCompressedText: numChar is too long\n"));
     return false;
@@ -1272,7 +1287,7 @@ bool MindWrtParser::readCompressedText(MindWrtParserInternal::LineInfo const &li
           MWAW_DEBUG_MSG(("MindWrtParser::readCompressedText: text is too long\n"));
           return false;
         }
-        actualChar = (int) input->readULong(1);
+        actualChar = static_cast<int>(input->readULong(1));
         actVal = (actualChar >> 4);
       }
       else
@@ -1280,7 +1295,7 @@ bool MindWrtParser::readCompressedText(MindWrtParserInternal::LineInfo const &li
       actualCharSet = !actualCharSet;
       if (st == 0) {
         if (actVal == 0xf) continue;
-        text += (char) m_state->m_compressCorr[(size_t) actVal];
+        text += char(m_state->m_compressCorr[size_t(actVal)]);
         break;
       }
       if (st == 1) { // high bytes
@@ -1291,7 +1306,7 @@ bool MindWrtParser::readCompressedText(MindWrtParserInternal::LineInfo const &li
         MWAW_DEBUG_MSG(("rser::readCompressedText: find 0 char\n"));
         continue;
       }
-      text += (char)(highByte | actVal);
+      text += char(highByte | actVal);
     }
   }
   f << text;
@@ -1333,7 +1348,7 @@ bool MindWrtParser::readFonts(MWAWEntry const &entry, std::vector<MWAWFont> &fon
     MWAW_DEBUG_MSG(("MindWrtParser::readFonts: zone is too short\n"));
     return false;
   }
-  int sz = (int) input->readULong(2);
+  auto sz = static_cast<int>(input->readULong(2));
   if (pos+2+sz > endPos || (sz%6)) {
     MWAW_DEBUG_MSG(("MindWrtParser::readFonts: sz is odd\n"));
     return false;
@@ -1347,12 +1362,12 @@ bool MindWrtParser::readFonts(MWAWEntry const &entry, std::vector<MWAWFont> &fon
     pos = input->tell();
     f.str("");
     f << "Text:Font" << i << ":";
-    int tPos = (int) input->readULong(2);
+    auto tPos = static_cast<int>(input->readULong(2));
     textPos.push_back(tPos);
     f << "pos=" << tPos << ",";
     MWAWFont font;
-    font.setSize((float) input->readULong(1));
-    int flag = (int) input->readULong(1);
+    font.setSize(float(input->readULong(1)));
+    auto flag = static_cast<int>(input->readULong(1));
     uint32_t flags = 0;
     // bit 1 = plain
     if (flag&0x1) flags |= MWAWFont::boldBit;
@@ -1364,7 +1379,7 @@ bool MindWrtParser::readFonts(MWAWEntry const &entry, std::vector<MWAWFont> &fon
     if (flag&0x40) font.set(MWAWFont::Script::sub100());
     if (flag&0x80) f << "#fFlags80,";
     font.setFlags(flags);
-    font.setId((int) input->readULong(2));
+    font.setId(static_cast<int>(input->readULong(2)));
     fonts.push_back(font);
 #ifdef DEBUG
     f << font.getDebugString(getFontConverter());
@@ -1401,8 +1416,7 @@ bool MindWrtParser::checkHeader(MWAWHeader *header, bool strict)
     header->reset(MWAWDocument::MWAW_T_MINDWRITE, 2);
 
   f << "Entries(Header):";
-  for (int i = 0; i < 3; i++)
-    m_state->m_numLinesByZone[i] = (int) input->readULong(2);
+  for (auto &num : m_state->m_numLinesByZone) num = static_cast<int>(input->readULong(2));
   f << "nLines=" << m_state->m_numLinesByZone[0] << ",";
   if (m_state->m_numLinesByZone[1])
     f << "nLines[Head]=" << m_state->m_numLinesByZone[1] << ",";
@@ -1417,7 +1431,7 @@ bool MindWrtParser::checkHeader(MWAWHeader *header, bool strict)
     val = input->readLong(2);
     if (val) f << "g" << i << "=" << val << ",";
   }
-  val = (long) input->readULong(2); // always 0x7fff
+  val = long(input->readULong(2)); // always 0x7fff
   if (val != 0x7fff) f << "g3=" << std::hex << val << std::dec << ",";
   ascii().addPos(0);
   ascii().addNote(f.str().c_str());
@@ -1428,7 +1442,7 @@ bool MindWrtParser::checkHeader(MWAWHeader *header, bool strict)
   val = input->readLong(2); // 0 or 0x80
   if (val) f << "f0=" << val << ",";
   for (int i = 1; i < 5; i++) { // 08, 0, [60|62], [40|60|66|70]
-    val = (long) input->readULong(1);
+    val = long(input->readULong(1));
     if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
   for (int i = 0; i < 2; i++) { // -1, -1|0
@@ -1440,10 +1454,10 @@ bool MindWrtParser::checkHeader(MWAWHeader *header, bool strict)
   }
   val = input->readLong(2); // always 1 ?
   if (val != 1) f << "g2=" << val << ",";
-  m_state->m_listProperties.m_startListIndex = (int) input->readULong(1)+1;
+  m_state->m_listProperties.m_startListIndex = static_cast<int>(input->readULong(1))+1;
   if (m_state->m_listProperties.m_startListIndex!=1)
     f << "list[start]=" << m_state->m_listProperties.m_startListIndex << ",";
-  val = (long) input->readULong(1);
+  val = long(input->readULong(1));
   if (val)
     f << "g3=" << val << ",";
 
@@ -1468,9 +1482,9 @@ bool MindWrtParser::checkHeader(MWAWHeader *header, bool strict)
   if (strict) {
     // check the line info block size
     input->seek(0x50, librevenge::RVNG_SEEK_SET);
-    for (int i = 0; i < 3; i++) {
+    for (int i : m_state->m_numLinesByZone) {
       input->seek(4, librevenge::RVNG_SEEK_CUR);
-      if (input->readLong(4) == 32*m_state->m_numLinesByZone[i])
+      if (input->readLong(4) == 32*i)
         continue;
       ok = false;
       break;
@@ -1511,29 +1525,29 @@ bool MindWrtParser::readLinesInfo(MWAWEntry &entry)
   int N = int(entry.length())/32;
 
   libmwaw::DebugStream f;
-  MindWrtParserInternal::ZoneInfo &textZone = m_state->m_zones[entry.id()];
+  auto &textZone = m_state->m_zones[entry.id()];
   textZone.m_linesList.clear();
   for (int n = 0; n < N; n++) {
     MindWrtParserInternal::LineInfo line;
 
     pos = input->tell();
     f.str("");
-    line.m_type = (int) input->readLong(1); // 0, fd, ff
-    line.m_height = (int) input->readULong(1);
-    line.m_y = (int) input->readLong(2);
-    line.m_page = (int)input->readULong(1); // check me
+    line.m_type = static_cast<int>(input->readLong(1)); // 0, fd, ff
+    line.m_height = static_cast<int>(input->readULong(1));
+    line.m_y = static_cast<int>(input->readLong(2));
+    line.m_page = static_cast<int>(input->readULong(1)); // check me
     long val = input->readLong(2); // -1 or between 5d7-5de
     f << "f0=" << std::hex << val << std::dec << ",";
     for (int i=0; i < 2; i++)
-      line.m_flags[i] = (int) input->readULong(1);
-    long ptr = (long) input->readULong(1);
-    line.m_entry.setBegin((ptr << 16) | (long) input->readULong(2));
-    line.m_entry.setLength((long) input->readULong(2));
+      line.m_flags[i] = static_cast<int>(input->readULong(1));
+    auto ptr = long(input->readULong(1));
+    line.m_entry.setBegin((ptr << 16) | long(input->readULong(2)));
+    line.m_entry.setLength(long(input->readULong(2)));
     line.m_extra=f.str();
     for (int i=2; i < 4; i++)
-      line.m_flags[i] = (int) input->readULong(1);
-    line.m_listLevel = (int) input->readLong(2);
-    line.m_listType = (int) input->readLong(2); //0: heading, 1: unlabelled 2: paragraph, 3: bullet
+      line.m_flags[i] = static_cast<int>(input->readULong(1));
+    line.m_listLevel = static_cast<int>(input->readLong(2));
+    line.m_listType = static_cast<int>(input->readLong(2)); //0: heading, 1: unlabelled 2: paragraph, 3: bullet
     /** 01[45]0 */
 
     textZone.m_linesList.push_back(line);
@@ -1549,8 +1563,7 @@ bool MindWrtParser::readLinesInfo(MWAWEntry &entry)
   // first, we must read and update the paragraph
   MWAWParagraph para;
   bool hasSpecialHeadInterface = false;
-  for (size_t n = 0; n < size_t(N); n++) {
-    MindWrtParserInternal::LineInfo &line=textZone.m_linesList[n];
+  for (auto &line : textZone.m_linesList) {
     if (line.m_height || line.m_type) {
       line.m_paragraph=para;
       line.m_specialHeadingInterface = hasSpecialHeadInterface;
@@ -1590,15 +1603,15 @@ bool MindWrtParser::readLastZone(MWAWEntry &entry)
   int N=int(entry.length()>>2)-2;
   long val;
   for (int i = 0; i < N; i++) { // find one time two value 0x154, 0xc ?
-    val = (long) input->readULong(4);
+    val = long(input->readULong(4));
     if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
   }
-  val = (long) input->readULong(4);
+  val = long(input->readULong(4));
   if (val != pos) {
     MWAW_DEBUG_MSG(("MindWrtParser::readLastZone: the ptr seems odd\n"));
     f << "#ptr=" << std::hex << val << std::dec << ",";
   }
-  val = (long) input->readULong(2); // always 0x7fff
+  val = long(input->readULong(2)); // always 0x7fff
   if (val != 0x7fff) f << "g0=" << std::hex << val << std::dec << ",";
   val = input->readLong(2); // always -1
   if (val != -1)  f << "g1=" << val << ",";
@@ -1628,8 +1641,8 @@ bool MindWrtParser::readHeadingStates(MWAWEntry &entry)
   if (unkn!=2) f << "unkn=" << unkn << ",";
   int N=int(entry.length()/2)-1;
   for (int i = 0; i < N; i++) {
-    int fl=(int) input->readULong(1);
-    int wh=(int) input->readULong(1);
+    auto fl=static_cast<int>(input->readULong(1));
+    auto wh=static_cast<int>(input->readULong(1));
     if (fl==0 && wh==4)
       continue;
     f << "L" << i << "=[";
@@ -1662,7 +1675,7 @@ bool MindWrtParser::readHeadingCustom(MWAWEntry &entry)
 {
   if (!entry.valid())
     return false;
-  int len=int(entry.length());
+  auto len=int(entry.length());
   if (len<16) {
     MWAW_DEBUG_MSG(("MindWrtParser::readHeadingCustom: the size seems odd\n"));
     return false;
@@ -1673,14 +1686,14 @@ bool MindWrtParser::readHeadingCustom(MWAWEntry &entry)
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   libmwaw::DebugStream f;
   f << "HeadCust:";
-  if ((int) input->readULong(2)!= len) {
+  if (static_cast<int>(input->readULong(2))!= len) {
     MWAW_DEBUG_MSG(("MindWrtParser::readHeadingCustom: the size field seems odd\n"));
     f << "###";
     ascii().addPos(pos);
     ascii().addNote(f.str().c_str());
     return false;
   }
-  int N=(int) input->readULong(2);
+  auto N=static_cast<int>(input->readULong(2));
   f << "N=" << N << ",";
   if (len < 16+2*N) {
     MWAW_DEBUG_MSG(("MindWrtParser::readHeadingCustom: N seems bads\n"));
@@ -1690,11 +1703,11 @@ bool MindWrtParser::readHeadingCustom(MWAWEntry &entry)
     return false;
   }
 
-  int val = (int) input->readLong(2);
+  auto val = static_cast<int>(input->readLong(2));
   m_state->m_listProperties.m_listLevelsRepeatPos = val;
   if (val) f << "repeatPos=" << val << ",";
-  int debDeplPos = (int) input->readLong(2);
-  int debStringPos = (int) input->readLong(2);
+  auto debDeplPos = static_cast<int>(input->readLong(2));
+  auto debStringPos = static_cast<int>(input->readLong(2));
   if (debDeplPos+2*N >= len || debStringPos > len) {
     f << "##deplPos=" << debDeplPos << ","
       << "##stringPos=" << debStringPos << ",";
@@ -1704,20 +1717,20 @@ bool MindWrtParser::readHeadingCustom(MWAWEntry &entry)
     return false;
   }
   for (int i = 0; i < 3; i++) { // always 0 ?
-    val = (int) input->readLong(2);
+    val = static_cast<int>(input->readLong(2));
     if (!val) continue;
     f << "f" << i << "=" << val << ",";
   }
-  input->seek(beginPos+(long) debDeplPos, librevenge::RVNG_SEEK_SET);
+  input->seek(beginPos+long(debDeplPos), librevenge::RVNG_SEEK_SET);
 
   std::vector<int> listPos;
   for (int i = 0; i < N; i++)
-    listPos.push_back((int) input->readLong(2));
+    listPos.push_back(static_cast<int>(input->readLong(2)));
   listPos.push_back(len);
 
   std::string str("");
   for (size_t i = 0; i < size_t(N); i++) {
-    input->seek(beginPos+(long) listPos[i], librevenge::RVNG_SEEK_SET);
+    input->seek(beginPos+long(listPos[i]), librevenge::RVNG_SEEK_SET);
     int sSz=listPos[i+1]-listPos[i];
     if (sSz < 0) {
       f << "###len"<<i<<"="<< sSz << ",";
@@ -1728,7 +1741,7 @@ bool MindWrtParser::readHeadingCustom(MWAWEntry &entry)
     MWAWListLevel level;
     bool seeIndex=false;
     for (int s = 0; s < sSz; s++) {
-      char c = (char) input->readULong(1);
+      auto c = char(input->readULong(1));
       int unicode;
       str+=c;
       if (c==0)
@@ -1737,7 +1750,7 @@ bool MindWrtParser::readHeadingCustom(MWAWEntry &entry)
       if (seeIndex && (s >= sSz-2) && (c==',' || c==';' || c==' ')) {
         if (s==sSz-1)
           break;
-        if ((char) input->readULong(1)==' ')
+        if (char(input->readULong(1))==' ')
           break;
         input->seek(-1, librevenge::RVNG_SEEK_CUR);
       }
@@ -1761,18 +1774,18 @@ bool MindWrtParser::readHeadingCustom(MWAWEntry &entry)
           break;
         default:
           seeIndex=false;
-          unicode = getParserState()->m_fontConverter->unicode(3, (unsigned char)c);
+          unicode = getParserState()->m_fontConverter->unicode(3, static_cast<unsigned char>(c));
           if (unicode==-1)
-            libmwaw::appendUnicode((unsigned char)c, level.m_prefix);
+            libmwaw::appendUnicode(static_cast<unsigned char>(c), level.m_prefix);
           else
             libmwaw::appendUnicode(uint32_t(unicode), level.m_prefix);
           break;
         }
         continue;
       }
-      unicode = getParserState()->m_fontConverter->unicode(3, (unsigned char)c);
+      unicode = getParserState()->m_fontConverter->unicode(3, static_cast<unsigned char>(c));
       if (unicode==-1)
-        libmwaw::appendUnicode((unsigned char)c, level.m_suffix);
+        libmwaw::appendUnicode(static_cast<unsigned char>(c), level.m_suffix);
       else
         libmwaw::appendUnicode(uint32_t(unicode), level.m_suffix);
     }
@@ -1805,7 +1818,7 @@ bool MindWrtParser::readHeadingProperties(MWAWEntry &entry)
   f << "HeadProp:";
   long val=input->readLong(1); // always 0 ?
   if (val) f << "f0=" << val << ",";
-  m_state->m_listProperties.m_headingStyle=(int) input->readULong(1);
+  m_state->m_listProperties.m_headingStyle=static_cast<int>(input->readULong(1));
   switch (m_state->m_listProperties.m_headingStyle) {
   case 1:
     f << "list[type]=Hardvard,"; // I. A. 1. a) i)
@@ -1835,7 +1848,7 @@ bool MindWrtParser::readHeadingProperties(MWAWEntry &entry)
     f << "#list[showOneLevel]=" << val << ",";
     break;
   }
-  val = (long) input->readULong(1); // short, long?
+  val = long(input->readULong(1)); // short, long?
   if (val)
     f << "f1=" << val << ",";
   long const expectedValues[]= {0,0x7ffe,0xf,0xc};
@@ -1849,9 +1862,9 @@ bool MindWrtParser::readHeadingProperties(MWAWEntry &entry)
     if (val)
       f << "g" << i << "=" << val << ",";
   }
-  val = (long) input->readULong(4); // 5e3be|5e3c2|5e49c|2975a4|69dce0|69e10c
+  val = long(input->readULong(4)); // 5e3be|5e3c2|5e49c|2975a4|69dce0|69e10c
   f << "ptr?=" << std::hex << val << std::dec << ",";
-  val = (long) input->readULong(4); // always FFFFFF?
+  val = long(input->readULong(4)); // always FFFFFF?
   if (val != 0xFFFFFF)
     f << "unkn?=" << std::hex << val << std::dec << ",";
   ascii().addPos(pos);
@@ -1880,10 +1893,10 @@ bool MindWrtParser::readZone8(MWAWEntry &entry)
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   libmwaw::DebugStream f;
   f << "Zone8:";
-  long val = (long) input->readULong(1);// fl0=0|1|2c|2d,
+  auto val = long(input->readULong(1));// fl0=0|1|2c|2d,
   if (val)
     f << "fl0=" << std::hex << val << std::dec << ",";
-  val = (long) input->readULong(1); // fl1=2b|6b|ab
+  val = long(input->readULong(1)); // fl1=2b|6b|ab
   if (val & 0x80) { // checkme
     f << "showFirstLevel?,";
     m_state->m_listProperties.m_showFirstLevel = true;
@@ -1901,8 +1914,7 @@ bool MindWrtParser::readZone8(MWAWEntry &entry)
       f << "f" << i << "=" << val << ",";
   }
   int dim[2];
-  for (int i = 0; i < 2; i++)
-    dim[i] = (int) input->readLong(2);
+  for (auto &d : dim) d = static_cast<int>(input->readLong(2));
   f << "dim=" << dim[0] << "x" << dim[1] << ",";
   for (int i = 0; i < 12; i++) { // always 0...
     val = input->readLong(2);
@@ -1934,13 +1946,13 @@ bool MindWrtParser::readHeadingFields(MWAWEntry &entry)
   long pos = entry.begin();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
 
-  int num = int(entry.length()/12);
+  auto num = int(entry.length()/12);
   if (num != 8) {
     MWAW_DEBUG_MSG(("MindWrtParser::readHeadingFields: the number of fields seems odd\n"));
   }
   libmwaw::DebugStream f;
   long val;
-  static MWAWField::Type const(listType[4])= {
+  static MWAWField::Type const listType[4] = {
     MWAWField::Date, MWAWField::Time, MWAWField::PageNumber, MWAWField::Title
   };
   for (int i = 0; i < num; i++) {
@@ -1948,10 +1960,9 @@ bool MindWrtParser::readHeadingFields(MWAWEntry &entry)
     MindWrtParserInternal::Field field(listType[i%4]);
     f.str("");
     int dim[2];
-    for (int j=0; j < 2; j++)
-      dim[j] = (int) input->readLong(j==0 ? 2:4);
+    for (int j=0; j < 2; j++) dim[j] = static_cast<int>(input->readLong(j==0 ? 2:4));
     field.m_pos=MWAWVec2i(dim[1], dim[0]);
-    static int const(expectedVal[3])= {3,12,0};
+    static int const expectedVal[3] = {3,12,0};
     for (int j=0; j < 3; j++) {
       val = input->readLong(2);
       if (val!=expectedVal[j])
@@ -2057,7 +2068,7 @@ void MindWrtParser::sendText(std::string const &text, std::vector<MWAWFont> cons
   for (size_t c = 0; c < numChar; c++) {
     if (actFontId < numFonts && int(c) == textPos[actFontId])
       getTextListener()->setFont(fonts[actFontId++]);
-    unsigned char ch = (unsigned char)text[c];
+    auto ch = static_cast<unsigned char>(text[c]);
     switch (ch) {
     case 0x9:
       getTextListener()->insertTab();
@@ -2066,7 +2077,7 @@ void MindWrtParser::sendText(std::string const &text, std::vector<MWAWFont> cons
       getTextListener()->insertEOL(c!=numChar-1);
       break;
     default:
-      getTextListener()->insertCharacter((unsigned char) ch);
+      getTextListener()->insertCharacter(static_cast<unsigned char>(ch));
       break;
     }
   }
