@@ -2414,7 +2414,7 @@ bool MsWksDBParser::readFormula()
     else {
       auto &field = listFields[size_t(nField)];
       std::string extra;
-      if (!field.m_isSerial && field.m_content.m_contentType==MWAWCellContent::C_FORMULA &&
+      if (pos+1+fVal<=endPos && !field.m_isSerial && field.m_content.m_contentType==MWAWCellContent::C_FORMULA &&
           m_document->readFormula(pos+1+fVal, field.m_content, extra))
         f << field << extra;
       else {
