@@ -65,6 +65,7 @@ struct Object {
     , m_pos()
     , m_name("")
     , m_id(-1)
+    , m_annotation()
     , m_extra("")
   {
     for (auto &id : m_ids) id=-1;
@@ -123,6 +124,9 @@ struct Object {
   //! some flags
   int m_flags[2];
 
+  //! the annotation entry
+  MWAWEntry m_annotation;
+
   //! some extra data
   std::string m_extra;
 };
@@ -188,6 +192,7 @@ struct State {
     , m_eot(-1)
     , m_endNote(false)
     , m_picturesMap()
+    , m_posToCommentMap()
     , m_actPage(0)
     , m_numPages(0)
     , m_headersId()
@@ -204,6 +209,8 @@ struct State {
   bool m_endNote;
   //! the map filePos -> Picture
   std::map<long, Picture> m_picturesMap;
+  //! the map textPos -> comment entry
+  std::map<long,MWAWEntry> m_posToCommentMap;
 
   //! the list of object ( mainZone, other zone)
   std::vector<Object> m_objectList[2];
@@ -233,7 +240,7 @@ public:
   {
   }
   //! constructor for header/footer
-  SubDocument(MsWrdParser &pars, MWAWInputStreamPtr const &input, MWAWEntry entry, libmwaw::SubDocumentType type)
+  SubDocument(MsWrdParser &pars, MWAWInputStreamPtr const &input, MWAWEntry const &entry, libmwaw::SubDocumentType type)
     : MWAWSubDocument(&pars, input, entry)
     , m_id(-1)
     , m_type(type)
@@ -288,6 +295,8 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType type
     parser->sendPicture(m_pictFPos, m_pictCPos, MWAWPosition::Frame);
   else if (m_type == libmwaw::DOC_HEADER_FOOTER)
     parser->send(m_zone);
+  else if (m_type == libmwaw::DOC_COMMENT_ANNOTATION)
+    parser->sendSimpleTextZone(listener, m_zone);
   else
     parser->send(m_id, type);
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
@@ -402,6 +411,35 @@ bool MsWrdParser::getColor(int id, MWAWColor &col) const
   return true;
 }
 
+void MsWrdParser::sendSimpleTextZone(MWAWListenerPtr &listener, MWAWEntry const &entry)
+{
+  if (!listener || !entry.valid()) return;
+  auto input=getInput();
+  if (input->size()<entry.end()) {
+    MWAW_DEBUG_MSG(("MsWrdParser::sendSimpleTextZone: entry seems bad\n"));
+    return;
+  }
+  long pos=input->tell();
+
+  input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
+  for (long i=0; i<entry.length(); ++i) {
+    char c=char(input->readULong(1));
+    switch (c) {
+    case 0x9:
+      listener->insertTab();
+      break;
+    case 0xd: // line break hard
+      if (i+1!=entry.length())
+        listener->insertEOL();
+      break;
+    default: // asume basic caracter, ie. will not works if Chinese, ...
+      listener->insertCharacter(static_cast<unsigned char>(c));
+      break;
+    }
+  }
+  input->seek(pos, librevenge::RVNG_SEEK_SET);
+}
+
 void MsWrdParser::sendFootnote(int id)
 {
   if (!getTextListener()) return;
@@ -948,7 +986,7 @@ bool MsWrdParser::readHeaderEndV3()
   flags = static_cast<int>(input->readULong(1));
   if (flags) // always 1
     f << "fl1=" << std::hex << flags << std::dec << ",";
-  char const *(wh[]) = { "note", "line", "page" };
+  char const *wh[] = { "note", "line", "page" };
   for (auto const *what : wh) {
     val = long(input->readULong(2));
     if (val == 1) continue;
@@ -1236,12 +1274,12 @@ bool MsWrdParser::readPrinter(MsWrdEntry &entry)
 ////////////////////////////////////////////////////////////
 bool MsWrdParser::readDocSum(MsWrdEntry &entry)
 {
-  if (entry.length() < 8) {
+  MWAWInputStreamPtr input = getInput();
+  if (entry.length() < 8 || !input->checkPosition(entry.end())) {
     MWAW_DEBUG_MSG(("MsWrdParser::readDocSum: the zone seems to short\n"));
     return false;
   }
 
-  MWAWInputStreamPtr input = getInput();
   long pos = entry.begin();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   libmwaw::DebugStream f;
@@ -1254,12 +1292,12 @@ bool MsWrdParser::readDocSum(MsWrdEntry &entry)
   entry.setParsed(true);
 
   if (sz != entry.length()) f << "#";
-  char const *(what[]) = { "title", "subject","author","version","keyword",
-                           "creator", "author1", "author2" // unsure why there are 4 authors...
-                         };
-  char const *(attribNames[]) = { "dc:title", "dc:subject", "meta:initial-creator", nullptr,
-                                  "meta:keywords", "dc:creator", nullptr, nullptr
-                                };
+  char const *what[] = { "title", "subject","author","version","keyword",
+                         "creator", "author1", "author2" // unsure why there are 4 authors...
+                       };
+  char const *attribNames[] = { "dc:title", "dc:subject", "meta:initial-creator", nullptr,
+                                "meta:keywords", "dc:creator", nullptr, nullptr
+                              };
   auto fontConverter = getFontConverter();
   for (int i = 0; i < 8; i++) {
     long actPos = input->tell();
@@ -1308,12 +1346,12 @@ bool MsWrdParser::readDocSum(MsWrdEntry &entry)
 bool MsWrdParser::readStringsZone(MsWrdEntry &entry, std::vector<std::string> &list)
 {
   list.resize(0);
-  if (entry.length() < 2) {
+  MWAWInputStreamPtr input = getInput();
+  if (entry.length() < 2 || !input->checkPosition(entry.end())) {
     MWAW_DEBUG_MSG(("MsWrdParser::readStringsZone: the zone seems to short\n"));
     return false;
   }
 
-  MWAWInputStreamPtr input = getInput();
   long pos = entry.begin();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   libmwaw::DebugStream f;
@@ -1401,10 +1439,15 @@ bool MsWrdParser::readObjects()
       listObject[i].m_name = list[i];
   }
 
+  std::map<long,MWAWEntry> posToComments;
   for (auto &listObject : m_state->m_objectList) {
-    for (auto &obj : listObject)
+    for (auto &obj : listObject) {
       readObject(obj);
+      if (obj.m_annotation.valid() && obj.m_textPos>=0)
+        posToComments[obj.m_textPos]=obj.m_annotation;
+    }
   }
+  m_state->m_posToCommentMap=posToComments;
   return true;
 }
 
@@ -1573,8 +1616,7 @@ bool MsWrdParser::readObject(MsWrdParserInternal::Object &obj)
   MsWrdEntry fileEntry = obj.getEntry();
   fileEntry.setParsed(true);
   m_entryMap.insert
-  (std::multimap<std::string, MsWrdEntry>::value_type
-   (fileEntry.type(), fileEntry));
+  (std::multimap<std::string, MsWrdEntry>::value_type(fileEntry.type(), fileEntry));
 
   long zoneEnd = pos+6+fSz;
   std::string name(""); // first equation, second "" or Equation Word?
@@ -1626,9 +1668,6 @@ bool MsWrdParser::readObject(MsWrdParserInternal::Object &obj)
     input->seek(pos+fSz+1, librevenge::RVNG_SEEK_SET);
     ascii().addDelimiter(input->tell(),'|');
   }
-  if (isAnnotation) {
-    MWAW_DEBUG_MSG(("MsWrdParser::readObject: find some annotations, not implemented\n"));
-  }
   pos = input->tell();
   if (pos+2>endPos) {
     if (pos!= endPos)
@@ -1675,7 +1714,7 @@ bool MsWrdParser::readObject(MsWrdParserInternal::Object &obj)
       std::string annotation("");
       for (int i = 0; i < fSz; i++)
         annotation += char(input->readULong(1));
-      if (annotation.length())
+      if (!annotation.empty())
         f << "annot[inText]=" << annotation << ",";
     }
 
@@ -1692,10 +1731,13 @@ bool MsWrdParser::readObject(MsWrdParserInternal::Object &obj)
       f << "###";
     }
     else {
+      // store the comment
+      obj.m_annotation.setBegin(input->tell());
+      obj.m_annotation.setLength(fSz);
       std::string annotation("");
       for (int i = 0; i < fSz; i++)
         annotation += char(input->readULong(1));
-      if (annotation.length())
+      if (!annotation.empty())
         f << "annot[comment]=" << annotation << ",";
     }
   }
@@ -1832,6 +1874,13 @@ void MsWrdParser::sendPicture(long fPos, int cPos, MWAWPosition::AnchorTo anchor
     MWAW_DEBUG_MSG(("MsWrdParser::sendPicture: listener is not set\n"));
     return;
   }
+  if ((anchor == MWAWPosition::Char || anchor == MWAWPosition::CharBaseLine) &&
+      m_state->m_posToCommentMap.find(long(cPos-1))!=m_state->m_posToCommentMap.end()) {
+    MWAWInputStreamPtr input = getInput();
+    std::shared_ptr<MWAWSubDocument> subdoc=std::make_shared<MsWrdParserInternal::SubDocument>(*this, input, m_state->m_posToCommentMap.find(long(cPos-1))->second, libmwaw::DOC_COMMENT_ANNOTATION);
+    getTextListener()->insertComment(subdoc);
+    return;
+  }
   if (m_state->m_picturesMap.find(fPos)==m_state->m_picturesMap.end()) {
     MWAW_DEBUG_MSG(("MsWrdParser::sendPicture: can not find picture for pos %lx\n", static_cast<long unsigned int>(fPos)));
     return;
@@ -1842,7 +1891,7 @@ void MsWrdParser::sendPicture(long fPos, int cPos, MWAWPosition::AnchorTo anchor
       (anchor == MWAWPosition::Char || anchor == MWAWPosition::CharBaseLine)) {
     std::shared_ptr<MsWrdParserInternal::SubDocument> subdoc
     (new MsWrdParserInternal::SubDocument(*this, input, fPos, cPos));
-    MWAWPosition pictPos(MWAWVec2f(pict.m_dim.min()), MWAWVec2f(pict.m_dim.size()), librevenge::RVNG_POINT);;
+    MWAWPosition pictPos(MWAWVec2f(pict.m_dim.min()), MWAWVec2f(pict.m_dim.size()), librevenge::RVNG_POINT);
     pictPos.setRelativePosition(MWAWPosition::Char,
                                 MWAWPosition::XLeft, MWAWPosition::YTop);
     pictPos.m_wrapping =  MWAWPosition::WBackground;
