@@ -123,7 +123,7 @@ class SubDocument final : public MWAWSubDocument
 public:
   SubDocument(MultiplanParser &parser, MWAWInputStreamPtr const &input, MWAWEntry const &entry)
     : MWAWSubDocument(&parser, input, entry)
-    , m_parser(parser)
+    , m_multiParser(parser)
   {
   }
 
@@ -138,7 +138,7 @@ public:
 
 protected:
   /** the main parser */
-  MultiplanParser &m_parser;
+  MultiplanParser &m_multiParser;
 };
 
 void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*type*/)
@@ -149,7 +149,7 @@ void SubDocument::parse(MWAWListenerPtr &listener, libmwaw::SubDocumentType /*ty
   }
 
   long pos = m_input->tell();
-  m_parser.sendText(m_zone);
+  m_multiParser.sendText(m_zone);
   m_input->seek(pos, librevenge::RVNG_SEEK_SET);
 }
 
@@ -158,7 +158,7 @@ bool SubDocument::operator!=(MWAWSubDocument const &doc) const
   if (MWAWSubDocument::operator!=(doc)) return true;
   auto const *sDoc = dynamic_cast<SubDocument const *>(&doc);
   if (!sDoc) return true;
-  if (&m_parser != &sDoc->m_parser) return true;
+  if (&m_multiParser != &sDoc->m_multiParser) return true;
   return false;
 }
 }
@@ -595,7 +595,7 @@ bool MultiplanParser::readLink(int pos, MWAWCellContent::FormulaInstruction &ins
     ok=true;
     auto fontConverter=getFontConverter();
     auto const fId=m_state->m_font.id();
-    librevenge::RVNGString name=instr.m_fileName.c_str();
+    librevenge::RVNGString name=instr.m_fileName;
     name.append(':');
     for (int i=0; i<dSz; ++i) {
       auto ch=static_cast<unsigned char>(input->readULong(1));
@@ -646,12 +646,12 @@ bool MultiplanParser::readLink(int pos, MWAWCellContent::FormulaInstruction &ins
 
 bool MultiplanParser::readLinkFilename(int pos, MWAWCellContent::FormulaInstruction &instr)
 {
+  MWAWInputStreamPtr input = getInput();
   auto const &entry=m_state->m_entries[5];
-  if (!entry.valid() || pos<0 || pos+10>entry.length()) {
+  if (!entry.valid() || pos<0 || pos+10>entry.length() || !input->checkPosition(entry.end())) {
     MWAW_DEBUG_MSG(("MultiplanParser::readLinkFilename: the pos %d seems bad\n", pos));
     return false;
   }
-  MWAWInputStreamPtr input = getInput();
   long actPos=input->tell();
   long begPos=entry.begin()+pos;
   input->seek(begPos, librevenge::RVNG_SEEK_SET);
@@ -683,9 +683,9 @@ bool MultiplanParser::readLinkFilename(int pos, MWAWCellContent::FormulaInstruct
       MWAW_DEBUG_MSG(("MultiplanParser::readLinkFilename: dir seems bad\n"));
     }
   }
-  instr.m_fileName=filename.cstr();
-  f << instr.m_fileName << ",";
-  instr.m_sheet="Sheet0";
+  instr.m_fileName=filename;
+  f << instr.m_fileName.cstr() << ",";
+  instr.m_sheet[0]="Sheet0";
   ascii().addPos(begPos);
   ascii().addNote(f.str().c_str());
   input->seek(actPos, librevenge::RVNG_SEEK_SET);
@@ -695,11 +695,11 @@ bool MultiplanParser::readLinkFilename(int pos, MWAWCellContent::FormulaInstruct
 bool MultiplanParser::readSharedData(int pos, int cellType, MWAWVec2i const &cellPos, MWAWCellContent &content)
 {
   auto const &entry=m_state->m_entries[7];
-  if (!entry.valid() || pos<0 || pos+3>entry.length()) {
+  MWAWInputStreamPtr input = getInput();
+  if (!entry.valid() || pos<0 || pos+3>entry.length() || !input->checkPosition(entry.end())) {
     MWAW_DEBUG_MSG(("MultiplanParser::readSharedData: the pos %d seems bad\n", pos));
     return false;
   }
-  MWAWInputStreamPtr input = getInput();
   long actPos=input->tell();
   long begPos=entry.begin()+pos;
   input->seek(begPos, librevenge::RVNG_SEEK_SET);
@@ -1042,7 +1042,7 @@ static Functions const s_listOperators[] = {
   { "", -2}, { "", -2}, { "", -2}, { "", -2},
 };
 
-char const *s_listFunctions[]= {
+static char const *s_listFunctions[]= {
   // 0
   "Count", "If", "IsNA", "IsError",
   "Sum", "Average", "Min", "Max",
@@ -1070,6 +1070,11 @@ bool MultiplanParser::readFormula(MWAWVec2i const &cellPos, std::vector<MWAWCell
 {
   formula.clear();
   MWAWInputStreamPtr input = getInput();
+  if (!input || !input->checkPosition(endPos)) {
+    MWAW_DEBUG_MSG(("MultiplanParser::readFormula: bad position\n"));
+    error="badPos###";
+    return false;
+  }
   std::vector<std::vector<MWAWCellContent::FormulaInstruction> > stack;
   auto const &listOperators=MultiplanParserInternal::s_listOperators;
   int const numOperators=int(MWAW_N_ELEMENTS(listOperators));
@@ -1469,14 +1474,14 @@ bool MultiplanParser::sendCell(MWAWVec2i const &cellPos, int p)
   auto it=m_state->m_cellPositionsSet.find(p);
   ++it;
   long endPos=it!=m_state->m_cellPositionsSet.end() ? entry.begin()+*it : entry.end();
-  if (endPos-pos<4) {
+  auto input=getInput();
+  if (endPos-pos<4 || !input->checkPosition(endPos)) {
     MWAW_DEBUG_MSG(("MultiplanParser::sendCell: a cell %d seems to short\n", p));
     f << "###";
     ascii().addPos(pos);
     ascii().addNote(f.str().c_str());
     return false;
   }
-  auto input=getInput();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   int formSize=int(input->readULong(1));
   if (formSize) f << "form[size]=" << std::hex << formSize << std::dec << ",";
