@@ -728,7 +728,7 @@ bool NisusWrtParser::createZones()
       if (it->first != cntrNames[z])
         break;
       MWAWEntry &entry = it++->second;
-      readCNTR(entry, NisusWrtStruct::ZoneType(z));
+      readCNTR(entry, int(NisusWrtStruct::ZoneType(z)));
     }
   }
   char const *numbResetNames[] = { "DPND", "FDPN", "HDPN" };
@@ -738,7 +738,7 @@ bool NisusWrtParser::createZones()
       if (it->first != numbResetNames[z])
         break;
       MWAWEntry &entry = it++->second;
-      readNumberingReset(entry, NisusWrtStruct::ZoneType(z));
+      readNumberingReset(entry, int(NisusWrtStruct::ZoneType(z)));
     }
   }
   char const *versionNames[] = { "VRS ", "FVRS", "HVRS" };
