@@ -779,6 +779,10 @@ bool NisusWrtText::readFontsList(MWAWEntry const &entry)
   }
   entry.setParsed(true);
   MWAWInputStreamPtr input = m_mainParser->rsrcInput();
+  if (!input || !input->checkPosition(entry.end())) {
+    MWAW_DEBUG_MSG(("NisusWrtText::readFontsList: the zone is too short\n"));
+    return false;
+  }
   libmwaw::DebugFile &asciiFile = m_mainParser->rsrcAscii();
   long pos = entry.begin();
   input->seek(pos, librevenge::RVNG_SEEK_SET);
