@@ -1391,7 +1391,7 @@ bool PowerPoint1Parser::readDocInfo(MWAWEntry const &entry)
     MWAW_DEBUG_MSG(("PowerPoint1Parser::readDocInfo: the page dimension seems bad\n"));
   }
   else {
-    double const unit=m_state->m_unit;
+    double const unit=double(m_state->m_unit);
     // checkme, maybe better to define a slide with pageSize and no margins
     getPageSpan().setFormOrientation(MWAWPageSpan::PORTRAIT);
     if (pageBox[0][1]>=paperBox[0][1])
