@@ -62,7 +62,10 @@ namespace PowerPoint7ParserInternal
 //! Internal: the basic information about a slide/notes/... zone in a PowerPoint7Parser
 struct SlideInfo {
   //! constructor
-  SlideInfo() : m_box(), m_displayMaster(true), m_hasBackground(false)
+  SlideInfo()
+    : m_box()
+    , m_displayMaster(true)
+    , m_hasBackground(false)
   {
   }
   //! the bdbox
@@ -146,11 +149,11 @@ struct State {
   //! the page dimension
   MWAWVec2i m_pageDimension;
   //! the graph parser
-  shared_ptr<PowerPoint7Graph> m_graphParser;
+  std::shared_ptr<PowerPoint7Graph> m_graphParser;
   //! the text parser
-  shared_ptr<PowerPoint7Text> m_textParser;
+  std::shared_ptr<PowerPoint7Text> m_textParser;
   //! the ole parser
-  shared_ptr<PowerPoint3OLE> m_oleParser;
+  std::shared_ptr<PowerPoint3OLE> m_oleParser;
   //! the list of slides
   std::vector<PowerPoint7Struct::SlideId> m_slideList;
   //! the master slide
@@ -170,8 +173,9 @@ struct State {
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-PowerPoint7Parser::PowerPoint7Parser(MWAWInputStreamPtr input, MWAWRSRCParserPtr rsrcParser, MWAWHeader *header) :
-  MWAWPresentationParser(input, rsrcParser, header), m_state(new PowerPoint7ParserInternal::State)
+PowerPoint7Parser::PowerPoint7Parser(MWAWInputStreamPtr const &input, MWAWRSRCParserPtr const &rsrcParser, MWAWHeader *header)
+  : MWAWPresentationParser(input, rsrcParser, header)
+  , m_state(new PowerPoint7ParserInternal::State)
 {
   setAsciiName("main-1");
   m_state->m_graphParser.reset(new PowerPoint7Graph(*this));
@@ -203,7 +207,7 @@ bool PowerPoint7Parser::getColor(int cId, MWAWColor &col) const
 ////////////////////////////////////////////////////////////
 void PowerPoint7Parser::parse(librevenge::RVNGPresentationInterface *docInterface)
 {
-  if (!getInput().get() || !checkHeader(0L))  throw(libmwaw::ParseException());
+  if (!getInput().get() || !checkHeader(nullptr))  throw(libmwaw::ParseException());
   bool ok = true;
   try {
     ok = createZones();
@@ -240,8 +244,7 @@ void PowerPoint7Parser::createDocument(librevenge::RVNGPresentationInterface *do
   }
 
   std::vector<MWAWPageSpan> pageList;
-  for (size_t p=0; p<m_state->m_slideList.size(); ++p) {
-    PowerPoint7Struct::SlideId const &id=m_state->m_slideList[p];
+  for (auto const &id : m_state->m_slideList) {
     if (!id.isValid()) continue;
     MWAWPageSpan ps(getPageSpan());
     bool showMaster=true;
@@ -334,7 +337,7 @@ bool PowerPoint7Parser::readDocRoot()
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2)); //3e8 followed by a
+    auto cType=int(input->readULong(2)); //3e8 followed by a
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -415,7 +418,7 @@ bool PowerPoint7Parser::readDocument(long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -485,7 +488,7 @@ bool PowerPoint7Parser::readDocAtom(int level, long lastPos)
     int val;
     for (int i=0; i<2; ++i) {
       int dim[2];
-      for (int j=0; j<2; ++j) dim[j]=int(input->readLong(4));
+      for (auto &d : dim) d=int(input->readLong(4));
       MWAWVec2i size(dim[0],dim[1]);
       if (i==0 && dim[0]>0 && dim[1]>0) {
         m_state->m_pageDimension=size;
@@ -494,7 +497,7 @@ bool PowerPoint7Parser::readDocAtom(int level, long lastPos)
         getPageSpan().setFormLength(double(size.y())/576.0);
         getPageSpan().setFormWidth(double(size.x())/576.0);
       }
-      char const *(wh[])= {"page","paper"};
+      char const *wh[]= {"page","paper"};
       f << "dim[" << wh[i] << "]=" << size << ",";
     }
     for (int i=0; i<2; ++i) { // f0=0|1, f1=1
@@ -543,7 +546,7 @@ bool PowerPoint7Parser::readSlideInformation(int level, long lastPos)
   }
   PowerPoint7ParserInternal::SlideInfo info;
   int dim[4];
-  for (int i=0; i<4; ++i) dim[i]=int(input->readLong(4));
+  for (auto &d : dim) d=int(input->readLong(4));
   info.m_box=MWAWBox2i(MWAWVec2i(dim[0],dim[1]),MWAWVec2i(dim[2],dim[3]));
   f << "box=" << info.m_box << ",";
   int val;
@@ -609,7 +612,7 @@ bool PowerPoint7Parser::readSlides(int level, long lastPos, bool master)
   bool pushSlideId=false, pushColor=false;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -745,7 +748,7 @@ bool PowerPoint7Parser::readNotes(int level, long lastPos)
   bool pushSlideId=false, pushColor=false;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -851,7 +854,7 @@ bool PowerPoint7Parser::readEnvironment(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -921,7 +924,7 @@ bool PowerPoint7Parser::readColorScheme(int level, long lastPos, std::vector<MWA
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1008,8 +1011,8 @@ bool PowerPoint7Parser::readSlideShowInfo(int level, long lastPos)
   }
   else {
     for (int i=0; i<6; ++i) {
-      int val=int(input->readLong(4));
-      int const(expected[])= {0,2,2,0,1,-1};
+      auto val=int(input->readLong(4));
+      int const expected[]= {0,2,2,0,1,-1};
       if (val!=expected[i])
         f << "f" << i << "=" << val << ",";
     }
@@ -1038,7 +1041,7 @@ bool PowerPoint7Parser::readSlideViewInfo(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1091,7 +1094,7 @@ bool PowerPoint7Parser::readGuideAtom(int level, long lastPos)
   }
   else {
     for (int i=0; i<4; ++i) { // f0=0|1
-      int val=int(input->readLong(2));
+      auto val=int(input->readLong(2));
       if (val) f << "f" << i << "=" << val << ",";
     }
   }
@@ -1133,7 +1136,7 @@ bool PowerPoint7Parser::readViewInfoAtom(int level, long lastPos)
       f << input->readLong(4) << ",";
     f << "],";
     for (int i=0; i<2; ++i) { // f0=0|1, f1=76-b8
-      int val=int(input->readLong(2));
+      auto val=int(input->readLong(2));
       if (val) f << "f" << i << "=" << val << ",";
     }
   }
@@ -1191,7 +1194,7 @@ bool PowerPoint7Parser::readVbaInfo(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1243,9 +1246,9 @@ bool PowerPoint7Parser::readVbaInfoAtom(int level, long lastPos)
     input->seek(header.m_dataSize, librevenge::RVNG_SEEK_CUR);
   }
   else {
-    int N=int(header.m_dataSize/4);
+    auto N=int(header.m_dataSize/4);
     for (int i=0; i<N; ++i) { // always 0
-      int val=int(input->readLong(4));
+      auto val=int(input->readLong(4));
       if (val) f << "f" << i << "=" << val << ",";
     }
     input->seek(pos+16+header.m_dataSize, librevenge::RVNG_SEEK_SET);
@@ -1277,8 +1280,8 @@ bool PowerPoint7Parser::readSSDocInfoAtom(int level, long lastPos)
   }
   else {
     for (int i=0; i<6; ++i) {
-      int val=int(input->readLong(2));
-      int const(expected[])= {1,0,0,0,0,0x100};
+      auto val=int(input->readLong(2));
+      int const expected[]= {1,0,0,0,0,0x100};
       if (val!=expected[i])
         f << "f" << i << "=" << val << ",";
     }
@@ -1307,7 +1310,7 @@ bool PowerPoint7Parser::readSummary(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1351,7 +1354,7 @@ bool PowerPoint7Parser::readZone1028(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1401,7 +1404,7 @@ bool PowerPoint7Parser::readZone1028Atom(int level, long lastPos)
   }
   else {
     for (int i=0; i<10; ++i) { // f0-f6=0|1,f7=f8=0, f9=d-b2
-      int val=int(input->readULong(1));
+      auto val=int(input->readULong(1));
       if (val==1)
         f << "f" << i << ",";
       else if (val)
@@ -1432,7 +1435,7 @@ bool PowerPoint7Parser::readOutlineViewInfo(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1476,7 +1479,7 @@ bool PowerPoint7Parser::readSorterViewInfo(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1537,7 +1540,7 @@ bool PowerPoint7Parser::readContainerList(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1674,7 +1677,7 @@ bool PowerPoint7Parser::readBookmarkCollection(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1726,7 +1729,7 @@ bool PowerPoint7Parser::readSoundCollection(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1770,7 +1773,7 @@ bool PowerPoint7Parser::readBookmarkSeedAtom(int level, long lastPos)
   }
   else {
     for (int i=0; i<2; ++i) { // f0=1
-      int val=int(input->readULong(2));
+      auto val=int(input->readULong(2));
       if (val) f << "f" << i << "=" << val << ",";
     }
   }
@@ -1798,7 +1801,7 @@ bool PowerPoint7Parser::readZone2026(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1853,11 +1856,11 @@ bool PowerPoint7Parser::readColorList(int level, long lastPos, std::vector<MWAWC
   }
   f << "colors=[";
   colors.resize(size_t(N));
-  for (size_t i=0; i<size_t(N); ++i) {
+  for (auto &color : colors) {
     unsigned char col[4];
-    for (int c=0; c<4; ++c) col[c]=static_cast<unsigned char>(input->readULong(1));
-    colors[i]=MWAWColor(col[0],col[1],col[2]);
-    f << colors[i] << ",";
+    for (auto &c : col) c=static_cast<unsigned char>(input->readULong(1));
+    color=MWAWColor(col[0],col[1],col[2]);
+    f << color << ",";
   }
   f << "],";
   if (input->tell()!=endPos) {
@@ -1888,7 +1891,7 @@ bool PowerPoint7Parser::readZone3000(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -1948,7 +1951,7 @@ bool PowerPoint7Parser::readZone3012(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -2005,7 +2008,7 @@ bool PowerPoint7Parser::readZone3012Atom(int level, long lastPos)
     input->seek(header.m_dataSize, librevenge::RVNG_SEEK_CUR);
   }
   else {
-    int val=int(input->readULong(2)); // 0
+    auto val=int(input->readULong(2)); // 0
     if (val)
       f << "f0=" << val << ",";
   }
@@ -2040,7 +2043,7 @@ bool PowerPoint7Parser::readTextCharsAtom(int level, long lastPos)
       if (!val) continue;
       f << "anchor" << (i==0 ? "LR" : "BT") << "=" << float(val)/8.f << "pt,";
     }
-    int val=int(input->readULong(1));
+    auto val=int(input->readULong(1));
     if (val&1) f << "adjust[text],";
     if (val&4) f << "wrap[word],";
     val&=0xfa;
@@ -2048,7 +2051,7 @@ bool PowerPoint7Parser::readTextCharsAtom(int level, long lastPos)
       f << "fl0=" << std::hex << val << std::dec << ",";
     for (int i=0; i<7; ++i) {
       val=int(input->readULong(1));
-      int const(expected[])= {0x6e,7,0x50,3,0xe0,0x62,0};
+      int const expected[]= {0x6e,7,0x50,3,0xe0,0x62,0};
       if (val==expected[i])
         continue;
       if (i==3) {
@@ -2084,7 +2087,7 @@ bool PowerPoint7Parser::readStyleTextPropAtom(int level, long lastPos, int &tId)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -2142,7 +2145,7 @@ bool PowerPoint7Parser::readOutlineTextProps9Atom(int level, long lastPos, int &
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -2207,7 +2210,7 @@ bool PowerPoint7Parser::readOutlineTextPropsHeader9Atom(int level, long lastPos)
   }
   else {
     for (int i=0; i<8; ++i) { // 0
-      int val=int(input->readULong(2));
+      auto val=int(input->readULong(2));
       if (val) f << "f" << i << "=" << val << ",";
     }
   }
@@ -2291,7 +2294,7 @@ bool PowerPoint7Parser::readKinsoku(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -2347,7 +2350,7 @@ bool PowerPoint7Parser::readZone4039(int level, long lastPos)
   }
 
   for (int i=0; i<16; ++i) { // f0=1010,f1=6,f14=f15=-1
-    int val=int(input->readLong(2));
+    auto val=int(input->readLong(2));
     if (val) f << "f" << i << "=" << val << ",";
   }
   input->seek(pos+16+header.m_dataSize, librevenge::RVNG_SEEK_SET);
@@ -2380,7 +2383,7 @@ bool PowerPoint7Parser::readHandout(int level, long lastPos)
   bool pushColor=false;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -2513,7 +2516,7 @@ bool PowerPoint7Parser::readSlideIdentifierContainer(int level, long lastPos, Po
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -2557,7 +2560,7 @@ bool PowerPoint7Parser::readHeaderFooters(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -2611,7 +2614,7 @@ bool PowerPoint7Parser::readHeaderFooterAtom(int level, long lastPos)
   else {
     f << "flags=[";
     for (int i=0; i<8; ++i) { // list of 0 and 1
-      int val=int(input->readULong(1));
+      auto val=int(input->readULong(1));
       if (val==1)
         f << "*,";
       else if (val)
@@ -2645,7 +2648,7 @@ bool PowerPoint7Parser::readZone4072(int level, long lastPos)
   long endPos=pos+16+header.m_dataSize;
   while (input->tell()<endPos) {
     pos=input->tell();
-    int cType=int(input->readULong(2));
+    auto cType=int(input->readULong(2));
     input->seek(pos, librevenge::RVNG_SEEK_SET);
 
     bool done=false;
@@ -2776,7 +2779,7 @@ bool PowerPoint7Parser::parseTextContent(MWAWInputStreamPtr input)
   input->seek(0, librevenge::RVNG_SEEK_SET);
   long pos=0;
   while (!input->isEnd()) {
-    char c=char(input->readULong(1));
+    auto c=char(input->readULong(1));
     if (c==0) {
       input->seek(-1, librevenge::RVNG_SEEK_CUR);
       break;
@@ -2807,22 +2810,20 @@ void PowerPoint7Parser::sendSlides()
     MWAW_DEBUG_MSG(("PowerPoint7Parser::sendSlides: can not find the listener\n"));
     return;
   }
-  std::map<PowerPoint7Struct::SlideId, librevenge::RVNGString>::const_iterator mIt;
-  for (mIt=m_state->m_masterSlideIdToNameMap.begin(); mIt!=m_state->m_masterSlideIdToNameMap.end(); ++mIt) {
-    if (!mIt->first.isValid()) continue;
+  for (auto mIt : m_state->m_masterSlideIdToNameMap) {
+    if (!mIt.first.isValid()) continue;
     MWAWPageSpan ps(getPageSpan());
-    ps.setMasterPageName(mIt->second);
+    ps.setMasterPageName(mIt.second);
     if (!listener->openMasterPage(ps)) {
       MWAW_DEBUG_MSG(("PowerPoint7Parser::sendSlides: can not create the master page\n"));
     }
     else {
-      m_state->m_graphParser->sendSlide(mIt->first,true);
+      m_state->m_graphParser->sendSlide(mIt.first,true);
       listener->closeMasterPage();
     }
   }
   bool firstSlideSent=false;
-  for (size_t p=0; p<m_state->m_slideList.size(); ++p) {
-    PowerPoint7Struct::SlideId const &id=m_state->m_slideList[p];
+  for (auto const &id : m_state->m_slideList) {
     if (!id.isValid()) continue;
     if (firstSlideSent)
       listener->insertBreak(MWAWListener::PageBreak);
@@ -2856,7 +2857,7 @@ bool PowerPoint7Parser::checkHeader(MWAWHeader *header, bool /*strict*/)
   input=input->getSubStreamByName("PowerPoint Document");
   if (!input || !getInput()->getSubStreamByName("PersistentStorage Directory"))
     return false;
-  long endPos=long(input->size());
+  auto endPos=long(input->size());
   input->setReadInverted(true);
   input->seek(0, librevenge::RVNG_SEEK_SET);
   if (endPos<116 || input->readULong(2)!=3) {
@@ -2864,7 +2865,7 @@ bool PowerPoint7Parser::checkHeader(MWAWHeader *header, bool /*strict*/)
     return false;
   }
   input->seek(8, librevenge::RVNG_SEEK_SET);
-  long dSz=long(input->readULong(4));
+  auto dSz=long(input->readULong(4));
   if (dSz<100 || endPos-16<dSz || 16+dSz>endPos) return false;
 
   setVersion(7);
