@@ -41,8 +41,9 @@
 #include "MWAWFont.hxx"
 #include "MWAWFontConverter.hxx"
 #include "MWAWParagraph.hxx"
+#include "MWAWSection.hxx"
 
-#include "RagTime5Parser.hxx"
+#include "RagTime5Document.hxx"
 #include "RagTime5StructManager.hxx"
 
 #include "RagTime5StyleManager.hxx"
@@ -70,7 +71,7 @@ struct ColorFieldParser final : public RagTime5StructManager::FieldParser {
     return s.str();
   }
   //! parse a field
-  bool parseField(RagTime5StructManager::Field &field, RagTime5Zone &/*zone*/, int /*n*/, libmwaw::DebugStream &f) final
+  bool parseField(RagTime5StructManager::Field &field, RagTime5Zone &/*zone*/, int n, libmwaw::DebugStream &f) final
   {
     if (field.m_type!=RagTime5StructManager::Field::T_FieldList) {
       MWAW_DEBUG_MSG(("RagTime5StyleManagerInternal::ColorFieldParser::parseField: find unexpected field type \n"));
@@ -82,8 +83,14 @@ struct ColorFieldParser final : public RagTime5StructManager::FieldParser {
       for (auto const &child : field.m_fieldList) {
         // checkme:
         if (child.m_type==RagTime5StructManager::Field::T_Color && child.m_fileType==0x84040) {
-          m_colorsList.push_back(child.m_color);
-          f << "color=" << child.m_color << "[" << child.m_longValue[0] << "],";
+          if (n>=0 && int(m_colorsList.size())<n)
+            m_colorsList.resize(size_t(n));
+          if (n>=1 && n<=int(m_colorsList.size()))
+            m_colorsList[size_t(n-1)]=child.m_color;
+          else {
+            MWAW_DEBUG_MSG(("RagTime5StyleManagerInternal::ColorFieldParser::parseField: find bad n\n"));
+            f << "col=" << child.m_color << "[###],";
+          }
           continue;
         }
         MWAW_DEBUG_MSG(("RagTime5StyleManagerInternal::ColorFieldParser::parseField: find some unknown color block\n"));
@@ -128,7 +135,7 @@ struct ColorFieldParser final : public RagTime5StructManager::FieldParser {
     return true;
   }
 
-  //! a map id to color
+  //! the list of color
   std::vector<MWAWColor> m_colorsList;
 };
 
@@ -296,9 +303,9 @@ void State::initColorsList()
 ////////////////////////////////////////////////////////////
 // constructor/destructor, ...
 ////////////////////////////////////////////////////////////
-RagTime5StyleManager::RagTime5StyleManager(RagTime5Parser &parser)
-  : m_mainParser(parser)
-  , m_parserState(parser.getParserState())
+RagTime5StyleManager::RagTime5StyleManager(RagTime5Document &doc)
+  : m_document(doc)
+  , m_parserState(doc.getParserState())
   , m_state(new RagTime5StyleManagerInternal::State)
 {
 }
@@ -313,7 +320,7 @@ RagTime5StyleManager::~RagTime5StyleManager()
 bool RagTime5StyleManager::readGraphicColors(RagTime5ClusterManager::Cluster &cluster)
 {
   RagTime5StyleManagerInternal::ColorFieldParser fieldParser;
-  if (!m_mainParser.readStructZone(cluster, fieldParser, 14))
+  if (!m_document.readStructZone(cluster.m_dataLink, fieldParser, 14, &cluster.m_nameLink))
     return false;
   m_state->m_colorsList=fieldParser.m_colorsList;
   return true;
@@ -323,7 +330,7 @@ bool RagTime5StyleManager::readGraphicStyles(RagTime5ClusterManager::Cluster &cl
 {
   m_state->initColorsList();
   RagTime5StyleManagerInternal::GraphicFieldParser fieldParser(m_state->m_colorsList);
-  if (!m_mainParser.readStructZone(cluster, fieldParser, 14))
+  if (!m_document.readStructZone(cluster.m_dataLink, fieldParser, 14, &cluster.m_nameLink))
     return false;
   if (fieldParser.m_styleList.empty())
     fieldParser.m_styleList.resize(1);
@@ -569,6 +576,26 @@ bool RagTime5StyleManager::updateBorderStyle(int gId, MWAWGraphicStyle &style, b
   return true;
 }
 
+bool RagTime5StyleManager::updateFrameStyle(int gId, MWAWGraphicStyle &style) const
+{
+  if (gId<=0 || gId>=static_cast<int>(m_state->m_graphicStyleList.size())) {
+    MWAW_DEBUG_MSG(("RagTime5StyleManager::updateSurfaceStyle: can not find graphic style %d\n", gId));
+    return false;
+  }
+  auto const &gStyle=m_state->m_graphicStyleList[size_t(gId)];
+  if (gStyle.m_colorsAlpha[0]<=0 && gStyle.m_colorsAlpha[0]>=0)
+    return true;
+  float alpha=gStyle.m_colorsAlpha[0]>=0 ? gStyle.m_colorsAlpha[0] : 1;
+  if (((gStyle.m_gradient>=1 && gStyle.m_gradient<=2) || gStyle.m_pattern) &&
+      gStyle.m_colors[0].isSet() && gStyle.m_colors[1].isSet())
+    style.setBackgroundColor(MWAWColor::barycenter(0.5, gStyle.m_colors[0].get(),
+                             0.5, gStyle.m_colors[1].get()),
+                             0.5f*gStyle.m_colorsAlpha[0]+0.5f*gStyle.m_colorsAlpha[1]);
+  else if (gStyle.m_colors[0].isSet())
+    style.setBackgroundColor(gStyle.m_colors[0].get(), alpha);
+  return true;
+}
+
 bool RagTime5StyleManager::updateSurfaceStyle(int gId, MWAWGraphicStyle &style) const
 {
   if (gId<=0 || gId>=static_cast<int>(m_state->m_graphicStyleList.size())) {
@@ -580,17 +607,18 @@ bool RagTime5StyleManager::updateSurfaceStyle(int gId, MWAWGraphicStyle &style)
     return true;
   float alpha=gStyle.m_colorsAlpha[0]>=0 ? gStyle.m_colorsAlpha[0] : 1;
   if (gStyle.m_gradient>=1 && gStyle.m_gradient<=2) {
-    style.m_gradientType=gStyle.m_gradient==2 ? MWAWGraphicStyle::G_Radial : MWAWGraphicStyle::G_Linear;
-    style.m_gradientStopList.resize(0);
+    auto &finalGrad=style.m_gradient;
+    finalGrad.m_type=gStyle.m_gradient==2 ? MWAWGraphicStyle::Gradient::G_Radial : MWAWGraphicStyle::Gradient::G_Linear;
+    finalGrad.m_stopList.resize(0);
     if (gStyle.m_gradient==1)
-      style.m_gradientStopList.push_back(MWAWGraphicStyle::GradientStop(0, MWAWColor::white()));
+      finalGrad.m_stopList.push_back(MWAWGraphicStyle::Gradient::Stop(0, MWAWColor::white()));
     else
-      style.m_gradientStopList.push_back(MWAWGraphicStyle::GradientStop(0, gStyle.m_colors[0].get()));
-    style.m_gradientStopList.push_back(MWAWGraphicStyle::GradientStop(1, gStyle.m_colors[1].get()));
+      finalGrad.m_stopList.push_back(MWAWGraphicStyle::Gradient::Stop(0, gStyle.m_colors[0].get()));
+    finalGrad.m_stopList.push_back(MWAWGraphicStyle::Gradient::Stop(1, gStyle.m_colors[1].get()));
     if (gStyle.m_gradientCenter.isSet())
-      style.m_gradientPercentCenter=*gStyle.m_gradientCenter;
+      finalGrad.m_percentCenter=*gStyle.m_gradientCenter;
     if (gStyle.m_gradientRotation>-1000)
-      style.m_gradientAngle=gStyle.m_gradientRotation+90;
+      finalGrad.m_angle=gStyle.m_gradientRotation+90;
   }
   else if (gStyle.m_pattern) {
     auto pat=*gStyle.m_pattern;
@@ -608,7 +636,7 @@ bool RagTime5StyleManager::updateSurfaceStyle(int gId, MWAWGraphicStyle &style)
 bool RagTime5StyleManager::readTextStyles(RagTime5ClusterManager::Cluster &cluster)
 {
   RagTime5StyleManagerInternal::TextFieldParser fieldParser;
-  if (!m_mainParser.readStructZone(cluster, fieldParser, 14))
+  if (!m_document.readStructZone(cluster.m_dataLink, fieldParser, 14, &cluster.m_nameLink))
     return false;
 
   if (fieldParser.m_styleList.empty())
@@ -744,10 +772,11 @@ void RagTime5StyleManager::updateTextStyles
   }
 }
 
-bool RagTime5StyleManager::updateTextStyles(int tId, MWAWFont &font, MWAWParagraph &para) const
+bool RagTime5StyleManager::updateTextStyles(int tId, MWAWFont &font, MWAWParagraph &para, MWAWSection &section, double totalWidth) const
 {
   font=MWAWFont();
   para=MWAWParagraph();
+  section=MWAWSection();
 
   if (tId<=0 || tId>=static_cast<int>(m_state->m_textStyleList.size())) {
     MWAW_DEBUG_MSG(("RagTime5StyleManager::updateTextStyles: can not find text style %d\n", tId));
@@ -882,6 +911,8 @@ bool RagTime5StyleManager::updateTextStyles(int tId, MWAWFont &font, MWAWParagra
     newTab.m_leaderCharacter=tab.m_leaderChar;
     para.m_tabs->push_back(newTab);
   }
+  if (totalWidth>0 && style.m_numColumns>1)
+    section.setColumns(style.m_numColumns, totalWidth/double(style.m_numColumns), librevenge::RVNG_POINT, style.m_columnGap>0 ? style.m_columnGap/72. : 0.05);
   return true;
 }
 
@@ -893,16 +924,16 @@ bool RagTime5StyleManager::readFormats(RagTime5ClusterManager::Cluster &cluster)
 
   std::map<int, librevenge::RVNGString> idToNameMap;
   if (!cluster.m_nameLink.empty()) {
-    m_mainParser.readUnicodeStringList(cluster.m_nameLink, idToNameMap);
-    cluster.m_nameLink=RagTime5ClusterManager::Link();
+    m_document.readUnicodeStringList(cluster.m_nameLink, idToNameMap);
+    cluster.m_nameLink=RagTime5ClusterManager::NameLink();
   }
   std::vector<long> decal;
   if (link.m_ids[0])
-    m_mainParser.readPositions(link.m_ids[0], decal);
+    m_document.readPositions(link.m_ids[0], decal);
   if (decal.empty())
     decal=link.m_longList;
   int const dataId=link.m_ids[1];
-  auto dataZone=m_mainParser.getDataZone(dataId);
+  auto dataZone=m_document.getDataZone(dataId);
   auto N=int(decal.size());
 
   if (!dataZone || !dataZone->m_entry.valid() ||
@@ -930,7 +961,10 @@ bool RagTime5StyleManager::readFormats(RagTime5ClusterManager::Cluster &cluster)
   input->setReadInverted(!dataZone->m_hiLoEndian);
   long debPos=entry.begin();
   long endPos=entry.end();
-
+  if (!input->checkPosition(endPos)) {
+    MWAW_DEBUG_MSG(("RagTime5StyleManager::readFormats:bad endPos\n"));
+    return false;
+  }
   m_state->m_formatList.resize(size_t(N ? N-1 : 0));
   for (int i=1; i<N; ++i) {
     long pos=debPos+decal[size_t(i-1)], endDPos=debPos+decal[size_t(i)];
@@ -951,8 +985,8 @@ bool RagTime5StyleManager::readFormats(RagTime5ClusterManager::Cluster &cluster)
       continue;
     }
     auto nId=static_cast<int>(input->readLong(2));
-    if (idToNameMap.find(nId)!=idToNameMap.end())
-      f << "\"" << idToNameMap.find(nId)->second.cstr() << "\",";
+    if (idToNameMap.find(i)!=idToNameMap.end())
+      f << "\"" << idToNameMap.find(i)->second.cstr() << "\",";
     else {
       MWAW_DEBUG_MSG(("RagTime5StyleManager::readFormats: can not find the format name for zone %d\n", dataId));
       f << "###name[id]=" << nId << ",";
@@ -1199,10 +1233,10 @@ bool RagTime5StyleManager::readFormats(RagTime5ClusterManager::Cluster &cluster)
         when the value are small ints, FormB(FormA(val)+1)=val
       */
       std::vector<long> data;
-      m_mainParser.readLongList(lnk, data);
+      m_document.readLongList(lnk, data);
     }
     else
-      m_mainParser.readFixedSizeZone(lnk, lnk.m_name);
+      m_document.readFixedSizeZone(lnk, lnk.m_name);
   }
 
   return true;
@@ -1241,15 +1275,20 @@ bool RagTime5StyleManager::GraphicStyle::read(MWAWInputStreamPtr &input, RagTime
   std::stringstream s;
   if (field.m_type==RagTime5StructManager::Field::T_Long) { // header
     switch (field.m_fileType) {
-    case 0x1460042: // -3-23
     case 0x148c042: // -2<->8
       if (field.m_longValue[0])
-        s << "H" << std::hex << field.m_fileType << std::dec << "=" << field.m_longValue[0] << ",";
+        s << "H" << RagTime5StyleManager::printType(field.m_fileType) << "=" << field.m_longValue[0] << ",";
       else
-        s << "H" << std::hex << field.m_fileType << std::dec << ",";
+        s << "H" << RagTime5StyleManager::printType(field.m_fileType) << ",";
       m_extra+=s.str();
       return true;
-    case 0x145e042: // -2<->24 : CHECKME related to parent id?
+    case 0x1460042: // -3-23
+      s << "lineStyle,";
+      if (field.m_longValue[0]!=-3)
+        s << "pId?=" << field.m_longValue[0] << ",";
+      m_extra += s.str();
+      return true;
+    case 0x145e042: // -2<->24 : fill style CHECKME related to parent id?
     case 0x1489842: // -2<->19
       m_parentId=static_cast<int>(field.m_longValue[0]);
       return true;
@@ -1265,14 +1304,15 @@ bool RagTime5StyleManager::GraphicStyle::read(MWAWInputStreamPtr &input, RagTime
       for (auto const &child : field.m_fieldList) {
         if (child.m_type==RagTime5StructManager::Field::T_Color && child.m_fileType==0x84040) {
           if (child.m_longValue[0]==50) {
-            if (child.m_longValue[1]>=0 && child.m_longValue[1] < long(colorList.size())) {
-              m_colors[wh]=colorList[size_t(child.m_longValue[1])];
-              continue;
+            if (!updateColor(field.m_fileType==0x7d02a, int(child.m_longValue[1])+1, colorList)) {
+              MWAW_DEBUG_MSG(("RagTime5StyleManager::GraphicStyle::read: find some unknown color %ld block\n", child.m_longValue[1]+1));
+              s << "###";
             }
-            MWAW_DEBUG_MSG(("RagTime5StyleManager::GraphicStyle::read: find some unknown color %ld block\n", child.m_longValue[1]));
-            s << "##colId=" << child.m_longValue[1] << ",";
+            s << "col=GC" << child.m_longValue[1]+1 << ",";
+            continue;
           }
           m_colors[wh]=child.m_color;
+          m_colorsAlpha[wh]=1; // checkme
           continue;
         }
         MWAW_DEBUG_MSG(("RagTime5StyleManager::GraphicStyle::read: find some unknown color %d block\n", wh));
@@ -1337,7 +1377,7 @@ bool RagTime5StyleManager::GraphicStyle::read(MWAWInputStreamPtr &input, RagTime
 
     case 0x14600ca:
       for (auto const &child : field.m_fieldList) {
-        if (child.m_type==RagTime5StructManager::Field::T_LongList && child.m_fileType==long(0x80033000)) {
+        if (child.m_type==RagTime5StructManager::Field::T_LongList && child.m_fileType==(unsigned long)(long(0x80033000))) {
           m_dash=child.m_longList;
           continue;
         }
@@ -1456,10 +1496,15 @@ bool RagTime5StyleManager::GraphicStyle::read(MWAWInputStreamPtr &input, RagTime
       m_extra+=s.str();
       return true;
     // unknown small id
-    case 0x145e11a: { // frequent
+    case 0x145e11a: // frequent
+    case 0x145e12a: {  // unknown small int 2|3
       for (auto const &child : field.m_fieldList) {
         if (child.m_type==RagTime5StructManager::Field::T_Long && child.m_fileType==0x17d5880) {
-          s << "#unkn0=" << child.m_longValue[0] << ",";
+          if (!updateColor(field.m_fileType==0x145e11a, int(child.m_longValue[0]), colorList)) {
+            MWAW_DEBUG_MSG(("RagTime5StyleManager::GraphicStyle::read: find some unknown color %ld block\n", child.m_longValue[0]));
+            s << "###";
+          }
+          s << "col=GC" << child.m_longValue[0] << ",";
           continue;
         }
         MWAW_DEBUG_MSG(("RagTime5StyleManager::GraphicStyle::read: find some unknown unkn0 block\n"));
@@ -1468,18 +1513,6 @@ bool RagTime5StyleManager::GraphicStyle::read(MWAWInputStreamPtr &input, RagTime
       m_extra+=s.str();
       return true;
     }
-    case 0x145e12a: // unknown small int 2|3
-      for (auto const &child : field.m_fieldList) {
-        if (child.m_type==RagTime5StructManager::Field::T_Long && child.m_fileType==0x17d5880) {
-          MWAW_DEBUG_MSG(("RagTime5StyleManager::GraphicStyle::read: find some unkn1 block\n"));
-          s << "#unkn1=" << child.m_longValue[0];
-          continue;
-        }
-        MWAW_DEBUG_MSG(("RagTime5StyleManager::GraphicStyle::read: find some unknown unkn1 block\n"));
-        s << "###unkn1=" << child << ",";
-      }
-      m_extra+=s.str();
-      return true;
     default:
       break;
     }
@@ -1516,14 +1549,26 @@ bool RagTime5StyleManager::GraphicStyle::read(MWAWInputStreamPtr &input, RagTime
   return false;
 }
 
+bool RagTime5StyleManager::GraphicStyle::updateColor(bool first, int colorId, std::vector<MWAWColor> const &colorList)
+{
+  if (colorId>=1 && colorId <= int(colorList.size())) {
+    auto const &color=colorList[size_t(colorId-1)];
+    m_colors[first ? 0 : 1]=color;
+    if (color.getAlpha()<255)
+      m_colorsAlpha[first ? 0 : 1]=float(color.getAlpha())/255.f;
+    return true;
+  }
+  return false;
+}
+
 void RagTime5StyleManager::GraphicStyle::insert(RagTime5StyleManager::GraphicStyle const &childStyle)
 {
   if (childStyle.m_width>=0) m_width=childStyle.m_width;
-  bool updateColor=true;
+  bool updateCol=true;
   if (childStyle.m_dash.isSet()) m_dash=childStyle.m_dash;
   if (childStyle.m_pattern) m_pattern=childStyle.m_pattern;
   if (childStyle.m_gradient>=0) m_gradient=childStyle.m_gradient;
-  else if (m_gradient==1) updateColor=false; // we need to use the gradient color
+  else if (m_gradient==1) updateCol=false; // we need to use the gradient color
   if (childStyle.m_gradientRotation>-1000) m_gradientRotation=childStyle.m_gradientRotation;
   if (childStyle.m_gradientCenter.isSet()) m_gradientCenter=childStyle.m_gradientCenter;
   if (childStyle.m_position>=0) m_position=childStyle.m_position;
@@ -1531,7 +1576,7 @@ void RagTime5StyleManager::GraphicStyle::insert(RagTime5StyleManager::GraphicSty
   if (childStyle.m_mitter>=0) m_mitter=childStyle.m_mitter;
   if (childStyle.m_limitPercent>=0) m_limitPercent=childStyle.m_limitPercent;
   if (childStyle.m_hidden.isSet()) m_hidden=childStyle.m_hidden;
-  if (updateColor) {
+  if (updateCol) {
     if (childStyle.m_colors[0].isSet()) m_colors[0]=*childStyle.m_colors[0];
     if (childStyle.m_colors[1].isSet()) m_colors[1]=*childStyle.m_colors[1];
     for (int i=0; i<2; ++i) {
@@ -1545,11 +1590,9 @@ void RagTime5StyleManager::GraphicStyle::insert(RagTime5StyleManager::GraphicSty
 std::ostream &operator<<(std::ostream &o, RagTime5StyleManager::GraphicStyle const &style)
 {
   if (style.m_parentId>-1000) {
-    if (style.m_parentId==-3)
-      o << "parent=def3,";
-    else if (style.m_parentId==-2)
-      o << "parent=def2,";
-    else
+    if (style.m_parentId<0)
+      o << "parent=def" << -style.m_parentId << ",";
+    else if (style.m_parentId)
       o << "parent=GS" << style.m_parentId << ",";
   }
   if (style.m_width>=0) o << "w=" << style.m_width << ",";
@@ -1635,7 +1678,7 @@ std::ostream &operator<<(std::ostream &o, RagTime5StyleManager::GraphicStyle con
     break;
   }
   if (style.m_limitPercent>=0 && style.m_limitPercent<1)
-    o << "limit=" << 100*style.m_limitPercent << "%";
+    o << "limit=" << 100*style.m_limitPercent << "%,";
   if (style.m_hidden.get())
     o << "hidden,";
   o << style.m_extra;
@@ -1713,9 +1756,9 @@ bool RagTime5StyleManager::TextStyle::read(RagTime5StructManager::Field const &f
     case 0x147e842: // always 0?
     case 0x14b2042: // always 0?
       if (field.m_longValue[0])
-        s << "H" << std::hex << field.m_fileType << std::dec << "=" << field.m_longValue[0] << ",";
+        s << "H" << RagTime5StyleManager::printType(field.m_fileType) << "=" << field.m_longValue[0] << ",";
       else
-        s << "H" << std::hex << field.m_fileType << std::dec << ",";
+        s << "H" << RagTime5StyleManager::printType(field.m_fileType) << ",";
       m_extra+=s.str();
       return true;
     case 0x1474042: // -1<->39 : CHECKME related to parent id?
@@ -1748,7 +1791,7 @@ bool RagTime5StyleManager::TextStyle::read(RagTime5StructManager::Field const &f
     }
     case 0x14741fa:
       for (auto const &child : field.m_fieldList) {
-        if (child.m_type==RagTime5StructManager::Field::T_LongList && child.m_fileType==long(0x80045080)) {
+        if (child.m_type==RagTime5StructManager::Field::T_LongList && child.m_fileType==(unsigned long)(long(0x80045080))) {
           for (auto val : child.m_longList)
             m_linkIdList.push_back(static_cast<int>(val));
           continue;
@@ -1780,7 +1823,7 @@ bool RagTime5StyleManager::TextStyle::read(RagTime5StructManager::Field const &f
           continue;
         }
         MWAW_DEBUG_MSG(("RagTime5StyleManager::TextStyle::read: find some unknown graphic style block\n"));
-        s << "###graph[" << std::hex << field.m_fileType << std::dec << "]=" << child << ",";
+        s << "###graph[" << RagTime5StyleManager::printType(field.m_fileType) << "]=" << child << ",";
       }
       m_extra+=s.str();
       return true;
@@ -1952,7 +1995,7 @@ bool RagTime5StyleManager::TextStyle::read(RagTime5StructManager::Field const &f
     case 0x147510a:
       if (field.m_fileType==0x14750ca) s << "#tab0";
       for (auto const &child : field.m_fieldList) {
-        if (child.m_type==RagTime5StructManager::Field::T_TabList && (child.m_fileType==long(0x81474040) || child.m_fileType==0x1474040)) {
+        if (child.m_type==RagTime5StructManager::Field::T_TabList && (child.m_fileType==(unsigned long)(long(0x81474040)) || child.m_fileType==0x1474040)) {
           m_tabList=child.m_tabList;
           continue;
         }
@@ -2021,7 +2064,7 @@ bool RagTime5StyleManager::TextStyle::read(RagTime5StructManager::Field const &f
           continue;
         }
         MWAW_DEBUG_MSG(("RagTime5StyleManager::TextStyle::read: find some unknown long=%lx block\n", static_cast<unsigned long>(field.m_fileType)));
-        s << "###long[" << std::hex << field.m_fileType << std::dec << "]=" << child << ",";
+        s << "###long[" << RagTime5StyleManager::printType(field.m_fileType) << "]=" << child << ",";
       }
       m_extra+=s.str();
       return true;
@@ -2414,7 +2457,7 @@ std::ostream &operator<<(std::ostream &o, RagTime5StyleManager::TextStyle const
 
   for (int i=0; i<4; ++i) {
     if (style.m_letterSpacings[i]<=0&&style.m_letterSpacings[i]>=0) continue;
-    static char const *wh[]= {"", "[unkn]", "[min]", "[max]"};
+    static char const *wh[]= {"", "[optimal]", "[min]", "[max]"};
     o << "letterSpacing" << wh[i] << "=" << style.m_letterSpacings[i] << ",";
   }
   if (style.m_widthStreching>=0)
