@@ -335,6 +335,9 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="DDAP") {
     checkFInfoType("DDFL+","DiskDoubler") || checkFInfoType("DiskDoubler");
   }
+  else if (m_fInfoCreator=="FAIR") {
+    checkFInfoType("FWXX","Fair Witness") || checkFInfoType("Fair Witness");
+  }
   else if (m_fInfoCreator=="FH50") {
     checkFInfoType("AGD1","FreeHand 5") || checkFInfoType("FreeHand 5");
   }
@@ -417,6 +420,9 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="MACW") {
     checkFInfoType("MWCT","MaxWrite 1.0") || checkFInfoType("MaxWrite 1.0");
   }
+  else if (m_fInfoCreator=="MART") {
+    checkFInfoType("RSGF","ReadySetGo 1") || checkFInfoType("RSGI","ReadySetGo 2") || checkFInfoType("ReadySetGo 1/2");
+  }
   else if (m_fInfoCreator=="MD40") {
     checkFInfoType("MDDC","MacDraft 4-5") || checkFInfoType("MSYM","MacDraft 4-5[lib]") ||
     checkFInfoType("MacDraft 4-5");
@@ -436,6 +442,9 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="MDPL") {
     checkFInfoType("DRWG","MacDraw II") || checkFInfoType("STAT","MacDraw II(template)") || checkFInfoType("MacDraw II");
   }
+  else if (m_fInfoCreator=="MEMR") {
+    checkFInfoType("RSGR","ReadySetGo 4.5") || checkFInfoType("ReadySetGo 4.5");
+  }
   else if (m_fInfoCreator=="MMBB") {
     checkFInfoType("MBBT","Mariner Write") || checkFInfoType("Mariner Write");
   }
@@ -449,6 +458,9 @@ bool File::readFileInformation()
   else if (m_fInfoCreator=="MPNT") {
     checkFInfoType("PNTG","MacPaint") || checkFInfoType("MacPaint");
   }
+  else if (m_fInfoCreator=="MRSM") {
+    checkFInfoType("RSGJ","ReadySetGo 3") || checkFInfoType("RSGK","ReadySetGo 4") || checkFInfoType("ReadySetGo 3/4");
+  }
   else if (m_fInfoCreator=="MSWD") {
     checkFInfoType("WDBN","Microsoft Word 3-5") ||
     checkFInfoType("GLOS","Microsoft Word 3-5[glossary]") ||
@@ -869,6 +881,10 @@ bool File::readDataInformation()
       }
     }
   }
+  if (val[0]==0x1e && val[1]==0 && val[2]==0x86) {
+    m_dataResult.push_back("ReadySetGo 3");
+    return true;
+  }
   if (val[0]==0 && val[1]==0 && val[2]==0 && val[3]==0 && val[4]==0) {
     input.seek(10, InputStream::SK_SET);
     unsigned endian=unsigned(input.readU16());
@@ -1010,10 +1026,16 @@ bool File::readDataInformation()
     m_dataResult.push_back("QuarkXpress 1");
   if (val[0] == 0x26 && val[1] == 0x26)
     m_dataResult.push_back("QuarkXpress 2");
+  if (val[0] == 0x78)
+    m_dataResult.push_back("ReadySetGo 1[unsure]");
   if (val[0] == 0x7704)
     m_dataResult.push_back("MindWrite");
   if (val[0] == 0x110)
     m_dataResult.push_back("WriterPlus");
+  if (val[0] == 0x190 && (val[1]&0xff00)==0)
+    m_dataResult.push_back("ReadySetGo 4.0[unsure]");
+  if (val[0] == 0x138b)
+    m_dataResult.push_back("ReadySetGo 4.5[unsure]");
   if (val[0]==0xdba5 && val[1]==0x2d00) {
     m_dataResult.push_back("Microsoft Word 2.0[pc]");
     return true;
